"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def get(hub, ctx, query_execution_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Returns information about a single execution of a query if you have access to the workgroup in which the query ran. Each time a query executes, information about the query execution is saved with a unique ID.

    Args:
        query_execution_id(str): The unique ID of the query execution.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.athena.query.execution.get(ctx, query_execution_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.athena.query.execution.get query_execution_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="athena",
        operation="get_query_execution",
        op_kwargs={"QueryExecutionId": query_execution_id},
    )


async def list_all(
    hub, ctx, next_token: str = None, max_results: int = None, work_group: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    Provides a list of available query execution IDs for the queries in the specified workgroup. If a workgroup is not specified, returns a list of query execution IDs for the primary workgroup. Requires you to have access to the workgroup in which the queries ran. For code samples using the AWS SDK for Java, see Examples and Code Samples in the Amazon Athena User Guide.

    Args:
        next_token(str, optional): A token generated by the Athena service that specifies where to continue pagination if a previous request was truncated. To obtain the next set of pages, pass in the NextToken from the response object of the previous page call. Defaults to None.
        max_results(int, optional): The maximum number of query executions to return in this request. Defaults to None.
        work_group(str, optional): The name of the workgroup from which queries are being returned. If a workgroup is not specified, a list of available query execution IDs for the queries in the primary workgroup is returned. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.athena.query.execution.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.athena.query.execution.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="athena",
        operation="list_query_executions",
        op_kwargs={
            "NextToken": next_token,
            "MaxResults": max_results,
            "WorkGroup": work_group,
        },
    )


async def start(
    hub,
    ctx,
    query_string: str,
    client_request_token: str = None,
    query_execution_context: Dict = None,
    result_configuration: Dict = None,
    work_group: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Runs the SQL query statements contained in the Query. Requires you to have access to the workgroup in which the query ran. Running queries against an external catalog requires GetDataCatalog permission to the catalog. For code samples using the AWS SDK for Java, see Examples and Code Samples in the Amazon Athena User Guide.

    Args:
        query_string(str): The SQL query statements to be executed.
        client_request_token(str, optional): A unique case-sensitive string used to ensure the request to create the query is idempotent (executes only once). If another StartQueryExecution request is received, the same response is returned and another query is not created. If a parameter has changed, for example, the QueryString, an error is returned.  This token is listed as not required because AWS SDKs (for example the AWS SDK for Java) auto-generate the token for users. If you are not using the AWS SDK or the AWS CLI, you must provide this token or the action will fail. . Defaults to None.
        query_execution_context(Dict, optional): The database within which the query executes. Defaults to None.
        result_configuration(Dict, optional): Specifies information about where and how to save the results of the query execution. If the query runs in a workgroup, then workgroup's settings may override query settings. This affects the query results location. The workgroup settings override is specified in EnforceWorkGroupConfiguration (true/false) in the WorkGroupConfiguration. See WorkGroupConfiguration$EnforceWorkGroupConfiguration. Defaults to None.
        work_group(str, optional): The name of the workgroup in which the query is being started. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.athena.query.execution.start(ctx, query_string=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.athena.query.execution.start query_string=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="athena",
        operation="start_query_execution",
        op_kwargs={
            "QueryString": query_string,
            "ClientRequestToken": client_request_token,
            "QueryExecutionContext": query_execution_context,
            "ResultConfiguration": result_configuration,
            "WorkGroup": work_group,
        },
    )


async def stop(hub, ctx, query_execution_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Stops a query execution. Requires you to have access to the workgroup in which the query ran. For code samples using the AWS SDK for Java, see Examples and Code Samples in the Amazon Athena User Guide.

    Args:
        query_execution_id(str): The unique ID of the query execution to stop.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.athena.query.execution.stop(ctx, query_execution_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.athena.query.execution.stop query_execution_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="athena",
        operation="stop_query_execution",
        op_kwargs={"QueryExecutionId": query_execution_id},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def detach(hub, ctx, distribution_name: str) -> Dict:
    r"""
    **Autogenerated function**

    Detaches an SSL/TLS certificate from your Amazon Lightsail content delivery network (CDN) distribution. After the certificate is detached, your distribution stops accepting traffic for all of the domains that are associated with the certificate.

    Args:
        distribution_name(str): The name of the distribution from which to detach the certificate. Use the GetDistributions action to get a list of distribution names that you can specify.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.lightsail.certificate.from_distribution.detach(
                ctx, distribution_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.lightsail.certificate.from_distribution.detach distribution_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="lightsail",
        operation="detach_certificate_from_distribution",
        op_kwargs={"distributionName": distribution_name},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def configure(
    hub,
    ctx,
    id_: str,
    egress_access_logs: Dict = None,
    ingress_access_logs: Dict = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Changes the Channel's properities to configure log subscription

    Args:
        egress_access_logs(Dict, optional): Configure egress access logging. Defaults to None.
        id_(str): The ID of the channel to log subscription.
        ingress_access_logs(Dict, optional): Configure ingress access logging. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.mediapackage.logs.configure(ctx, id_=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.mediapackage.logs.configure id_=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="mediapackage",
        operation="configure_logs",
        op_kwargs={
            "EgressAccessLogs": egress_access_logs,
            "Id": id_,
            "IngressAccessLogs": ingress_access_logs,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


__func_alias__ = {"list_": "list"}


async def list_(hub, ctx, resource_type: str, resource_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Returns a list of the tags assigned to the specified resource. For information about the ID format for each supported resource type, see AddTagsToResource.

    Args:
        resource_type(str): Returns a list of tags for a specific resource type.
        resource_id(str): The resource ID for which you want to see a list of tags.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ssm.tags.for_resource.list(
                ctx, resource_type=value, resource_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ssm.tags.for_resource.list resource_type=value, resource_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ssm",
        operation="list_tags_for_resource",
        op_kwargs={"ResourceType": resource_type, "ResourceId": resource_id},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def describe(
    hub,
    ctx,
    cluster_identifier: str,
    database: str,
    connected_database: str = None,
    db_user: str = None,
    max_results: int = None,
    next_token: str = None,
    schema: str = None,
    secret_arn: str = None,
    table: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Describes the detailed information about a table from metadata in the cluster. The information includes its columns. A token is returned to page through the column list. Depending on the authorization method, use one of the following combinations of request parameters:    Secrets Manager - specify the Amazon Resource Name (ARN) of the secret, the database name, and the cluster identifier that matches the cluster in the secret.    Temporary credentials - specify the cluster identifier, the database name, and the database user name. Permission to call the redshift:GetClusterCredentials operation is required to use this method.

    Args:
        cluster_identifier(str): The cluster identifier. This parameter is required when authenticating using either Secrets Manager or temporary credentials. .
        connected_database(str, optional): A database name. The connected database is specified when you connect with your authentication credentials. . Defaults to None.
        database(str): The name of the database that contains the tables to be described. If ConnectedDatabase is not specified, this is also the database to connect to with your authentication credentials.
        db_user(str, optional): The database user name. This parameter is required when authenticating using temporary credentials. . Defaults to None.
        max_results(int, optional): The maximum number of tables to return in the response. If more tables exist than fit in one response, then NextToken is returned to page through the results. . Defaults to None.
        next_token(str, optional): A value that indicates the starting point for the next set of response records in a subsequent request. If a value is returned in a response, you can retrieve the next set of records by providing this returned NextToken value in the next NextToken parameter and retrying the command. If the NextToken field is empty, all response records have been retrieved for the request. . Defaults to None.
        schema(str, optional): The schema that contains the table. If no schema is specified, then matching tables for all schemas are returned. . Defaults to None.
        secret_arn(str, optional): The name or ARN of the secret that enables access to the database. This parameter is required when authenticating using Secrets Manager. . Defaults to None.
        table(str, optional): The table name. If no table is specified, then all tables for all matching schemas are returned. If no table and no schema is specified, then all tables for all schemas in the database are returned. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.redshift_data.table.describe(
                ctx, cluster_identifier=value, database=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.redshift_data.table.describe cluster_identifier=value, database=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="redshift-data",
        operation="describe_table",
        op_kwargs={
            "ClusterIdentifier": cluster_identifier,
            "ConnectedDatabase": connected_database,
            "Database": database,
            "DbUser": db_user,
            "MaxResults": max_results,
            "NextToken": next_token,
            "Schema": schema,
            "SecretArn": secret_arn,
            "Table": table,
        },
    )


async def list_all(
    hub,
    ctx,
    cluster_identifier: str,
    database: str,
    connected_database: str = None,
    db_user: str = None,
    max_results: int = None,
    next_token: str = None,
    schema_pattern: str = None,
    secret_arn: str = None,
    table_pattern: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    List the tables in a database. If neither SchemaPattern nor TablePattern are specified, then all tables in the database are returned. A token is returned to page through the table list. Depending on the authorization method, use one of the following combinations of request parameters:    Secrets Manager - specify the Amazon Resource Name (ARN) of the secret, the database name, and the cluster identifier that matches the cluster in the secret.    Temporary credentials - specify the cluster identifier, the database name, and the database user name. Permission to call the redshift:GetClusterCredentials operation is required to use this method.

    Args:
        cluster_identifier(str): The cluster identifier. This parameter is required when authenticating using either Secrets Manager or temporary credentials. .
        connected_database(str, optional): A database name. The connected database is specified when you connect with your authentication credentials. . Defaults to None.
        database(str): The name of the database that contains the tables to list. If ConnectedDatabase is not specified, this is also the database to connect to with your authentication credentials.
        db_user(str, optional): The database user name. This parameter is required when authenticating using temporary credentials. . Defaults to None.
        max_results(int, optional): The maximum number of tables to return in the response. If more tables exist than fit in one response, then NextToken is returned to page through the results. . Defaults to None.
        next_token(str, optional): A value that indicates the starting point for the next set of response records in a subsequent request. If a value is returned in a response, you can retrieve the next set of records by providing this returned NextToken value in the next NextToken parameter and retrying the command. If the NextToken field is empty, all response records have been retrieved for the request. . Defaults to None.
        schema_pattern(str, optional): A pattern to filter results by schema name. Within a schema pattern, "%" means match any substring of 0 or more characters and "_" means match any one character. Only schema name entries matching the search pattern are returned. If SchemaPattern is not specified, then all tables that match TablePattern are returned. If neither SchemaPattern or TablePattern are specified, then all tables are returned. . Defaults to None.
        secret_arn(str, optional): The name or ARN of the secret that enables access to the database. This parameter is required when authenticating using Secrets Manager. . Defaults to None.
        table_pattern(str, optional): A pattern to filter results by table name. Within a table pattern, "%" means match any substring of 0 or more characters and "_" means match any one character. Only table name entries matching the search pattern are returned. If TablePattern is not specified, then all tables that match SchemaPatternare returned. If neither SchemaPattern or TablePattern are specified, then all tables are returned. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.redshift_data.table.list_all(
                ctx, cluster_identifier=value, database=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.redshift_data.table.list_all cluster_identifier=value, database=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="redshift-data",
        operation="list_tables",
        op_kwargs={
            "ClusterIdentifier": cluster_identifier,
            "ConnectedDatabase": connected_database,
            "Database": database,
            "DbUser": db_user,
            "MaxResults": max_results,
            "NextToken": next_token,
            "SchemaPattern": schema_pattern,
            "SecretArn": secret_arn,
            "TablePattern": table_pattern,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub,
    ctx,
    certificate_authority_arn: str,
    principal: str,
    actions: List,
    source_account: str = None,
) -> None:
    r"""
    **Autogenerated function**

    Grants one or more permissions on a private CA to the AWS Certificate Manager (ACM) service principal (acm.amazonaws.com). These permissions allow ACM to issue and renew ACM certificates that reside in the same AWS account as the CA. You can list current permissions with the ListPermissions action and revoke them with the DeletePermission action.  About Permissions    If the private CA and the certificates it issues reside in the same account, you can use CreatePermission to grant permissions for ACM to carry out automatic certificate renewals.   For automatic certificate renewal to succeed, the ACM service principal needs permissions to create, retrieve, and list certificates.   If the private CA and the ACM certificates reside in different accounts, then permissions cannot be used to enable automatic renewals. Instead, the ACM certificate owner must set up a resource-based policy to enable cross-account issuance and renewals. For more information, see Using a Resource Based Policy with ACM Private CA.

    Args:
        certificate_authority_arn(str): The Amazon Resource Name (ARN) of the CA that grants the permissions. You can find the ARN by calling the ListCertificateAuthorities action. This must have the following form:   arn:aws:acm-pca:region:account:certificate-authority/12345678-1234-1234-1234-123456789012 . .
        principal(str): The AWS service or identity that receives the permission. At this time, the only valid principal is acm.amazonaws.com.
        source_account(str, optional): The ID of the calling account. Defaults to None.
        actions(List): The actions that the specified AWS service principal can use. These include IssueCertificate, GetCertificate, and ListPermissions.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.acm_pca.permission.create(
                ctx, certificate_authority_arn=value, principal=value, actions=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.acm_pca.permission.create certificate_authority_arn=value, principal=value, actions=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="acm-pca",
        operation="create_permission",
        op_kwargs={
            "CertificateAuthorityArn": certificate_authority_arn,
            "Principal": principal,
            "SourceAccount": source_account,
            "Actions": actions,
        },
    )


async def delete(
    hub, ctx, certificate_authority_arn: str, principal: str, source_account: str = None
) -> None:
    r"""
    **Autogenerated function**

    Revokes permissions on a private CA granted to the AWS Certificate Manager (ACM) service principal (acm.amazonaws.com).  These permissions allow ACM to issue and renew ACM certificates that reside in the same AWS account as the CA. If you revoke these permissions, ACM will no longer renew the affected certificates automatically. Permissions can be granted with the CreatePermission action and listed with the ListPermissions action.   About Permissions    If the private CA and the certificates it issues reside in the same account, you can use CreatePermission to grant permissions for ACM to carry out automatic certificate renewals.   For automatic certificate renewal to succeed, the ACM service principal needs permissions to create, retrieve, and list certificates.   If the private CA and the ACM certificates reside in different accounts, then permissions cannot be used to enable automatic renewals. Instead, the ACM certificate owner must set up a resource-based policy to enable cross-account issuance and renewals. For more information, see Using a Resource Based Policy with ACM Private CA.

    Args:
        certificate_authority_arn(str): The Amazon Resource Number (ARN) of the private CA that issued the permissions. You can find the CA's ARN by calling the ListCertificateAuthorities action. This must have the following form:   arn:aws:acm-pca:region:account:certificate-authority/12345678-1234-1234-1234-123456789012 . .
        principal(str): The AWS service or identity that will have its CA permissions revoked. At this time, the only valid service principal is acm.amazonaws.com .
        source_account(str, optional): The AWS account that calls this action. Defaults to None.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.acm_pca.permission.delete(
                ctx, certificate_authority_arn=value, principal=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.acm_pca.permission.delete certificate_authority_arn=value, principal=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="acm-pca",
        operation="delete_permission",
        op_kwargs={
            "CertificateAuthorityArn": certificate_authority_arn,
            "Principal": principal,
            "SourceAccount": source_account,
        },
    )


async def list_all(
    hub,
    ctx,
    certificate_authority_arn: str,
    next_token: str = None,
    max_results: int = None,
) -> Dict:
    r"""
    **Autogenerated function**

    List all permissions on a private CA, if any, granted to the AWS Certificate Manager (ACM) service principal (acm.amazonaws.com).  These permissions allow ACM to issue and renew ACM certificates that reside in the same AWS account as the CA.  Permissions can be granted with the CreatePermission action and revoked with the DeletePermission action.  About Permissions    If the private CA and the certificates it issues reside in the same account, you can use CreatePermission to grant permissions for ACM to carry out automatic certificate renewals.   For automatic certificate renewal to succeed, the ACM service principal needs permissions to create, retrieve, and list certificates.   If the private CA and the ACM certificates reside in different accounts, then permissions cannot be used to enable automatic renewals. Instead, the ACM certificate owner must set up a resource-based policy to enable cross-account issuance and renewals. For more information, see Using a Resource Based Policy with ACM Private CA.

    Args:
        certificate_authority_arn(str): The Amazon Resource Number (ARN) of the private CA to inspect. You can find the ARN by calling the ListCertificateAuthorities action. This must be of the form: arn:aws:acm-pca:region:account:certificate-authority/12345678-1234-1234-1234-123456789012 You can get a private CA's ARN by running the ListCertificateAuthorities action.
        next_token(str, optional): When paginating results, use this parameter in a subsequent request after you receive a response with truncated results. Set it to the value of NextToken from the response you just received. Defaults to None.
        max_results(int, optional): When paginating results, use this parameter to specify the maximum number of items to return in the response. If additional items exist beyond the number you specify, the NextToken element is sent in the response. Use this NextToken value in a subsequent request to retrieve additional items. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.acm_pca.permission.list_all(
                ctx, certificate_authority_arn=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.acm_pca.permission.list_all certificate_authority_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="acm-pca",
        operation="list_permissions",
        op_kwargs={
            "CertificateAuthorityArn": certificate_authority_arn,
            "NextToken": next_token,
            "MaxResults": max_results,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def describe_all(
    hub,
    ctx,
    filter_: List = None,
    max_duration: int = None,
    max_results: int = None,
    min_duration: int = None,
    next_token: str = None,
    offering_id: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Describes the Dedicated Host reservations that are available to purchase. The results describe all of the Dedicated Host reservation offerings, including offerings that might not match the instance family and Region of your Dedicated Hosts. When purchasing an offering, ensure that the instance family and Region of the offering matches that of the Dedicated Hosts with which it is to be associated. For more information about supported instance types, see Dedicated Hosts in the Amazon EC2 User Guide.

    Args:
        filter_(List, optional): The filters.    instance-family - The instance family of the offering (for example, m4).    payment-option - The payment option (NoUpfront | PartialUpfront | AllUpfront).  . Defaults to None.
        max_duration(int, optional): This is the maximum duration of the reservation to purchase, specified in seconds. Reservations are available in one-year and three-year terms. The number of seconds specified must be the number of seconds in a year (365x24x60x60) times one of the supported durations (1 or 3). For example, specify 94608000 for three years. Defaults to None.
        max_results(int, optional): The maximum number of results to return for the request in a single page. The remaining results can be seen by sending another request with the returned nextToken value. This value can be between 5 and 500. If maxResults is given a larger value than 500, you receive an error. Defaults to None.
        min_duration(int, optional): This is the minimum duration of the reservation you'd like to purchase, specified in seconds. Reservations are available in one-year and three-year terms. The number of seconds specified must be the number of seconds in a year (365x24x60x60) times one of the supported durations (1 or 3). For example, specify 31536000 for one year. Defaults to None.
        next_token(str, optional): The token to use to retrieve the next page of results. Defaults to None.
        offering_id(str, optional): The ID of the reservation offering. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ec2.host.reservation.offering.describe_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ec2.host.reservation.offering.describe_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ec2",
        operation="describe_host_reservation_offerings",
        op_kwargs={
            "Filter": filter_,
            "MaxDuration": max_duration,
            "MaxResults": max_results,
            "MinDuration": min_duration,
            "NextToken": next_token,
            "OfferingId": offering_id,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def describe_all(
    hub,
    ctx,
    repository_name: str,
    registry_id: str = None,
    next_token: str = None,
    max_results: int = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Returns the image tag details for a repository in a public registry.

    Args:
        registry_id(str, optional): The AWS account ID associated with the public registry that contains the repository in which to describe images. If you do not specify a registry, the default public registry is assumed. Defaults to None.
        repository_name(str): The name of the repository that contains the image tag details to describe.
        next_token(str, optional): The nextToken value returned from a previous paginated DescribeImageTags request where maxResults was used and the results exceeded the value of that parameter. Pagination continues from the end of the previous results that returned the nextToken value. This value is null when there are no more results to return. This option cannot be used when you specify images with imageIds. Defaults to None.
        max_results(int, optional): The maximum number of repository results returned by DescribeImageTags in paginated output. When this parameter is used, DescribeImageTags only returns maxResults results in a single page along with a nextToken response element. The remaining results of the initial request can be seen by sending another DescribeImageTags request with the returned nextToken value. This value can be between 1 and 1000. If this parameter is not used, then DescribeImageTags returns up to 100 results and a nextToken value, if applicable. This option cannot be used when you specify images with imageIds. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ecr_public.image.tag.describe_all(ctx, repository_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ecr_public.image.tag.describe_all repository_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ecr-public",
        operation="describe_image_tags",
        op_kwargs={
            "registryId": registry_id,
            "repositoryName": repository_name,
            "nextToken": next_token,
            "maxResults": max_results,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def disable(hub, ctx, admin_account_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Disables an AWS account within the Organization as the GuardDuty delegated administrator.

    Args:
        admin_account_id(str): The AWS Account ID for the organizations account to be disabled as a GuardDuty delegated administrator.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.guardduty.organization.admin_account.disable(
                ctx, admin_account_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.guardduty.organization.admin_account.disable admin_account_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="guardduty",
        operation="disable_organization_admin_account",
        op_kwargs={"AdminAccountId": admin_account_id},
    )


async def enable(hub, ctx, admin_account_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Enables an AWS account within the organization as the GuardDuty delegated administrator.

    Args:
        admin_account_id(str): The AWS Account ID for the organization account to be enabled as a GuardDuty delegated administrator.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.guardduty.organization.admin_account.enable(
                ctx, admin_account_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.guardduty.organization.admin_account.enable admin_account_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="guardduty",
        operation="enable_organization_admin_account",
        op_kwargs={"AdminAccountId": admin_account_id},
    )


async def list_all(hub, ctx, max_results: int = None, next_token: str = None) -> Dict:
    r"""
    **Autogenerated function**

    Lists the accounts configured as GuardDuty delegated administrators.

    Args:
        max_results(int, optional): The maximum number of results to return in the response. Defaults to None.
        next_token(str, optional): A token to use for paginating results that are returned in the response. Set the value of this parameter to null for the first request to a list action. For subsequent calls, use the NextToken value returned from the previous request to continue listing results after the first page. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.guardduty.organization.admin_account.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.guardduty.organization.admin_account.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="guardduty",
        operation="list_organization_admin_accounts",
        op_kwargs={"MaxResults": max_results, "NextToken": next_token},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def delete(hub, ctx, resource_arn: str) -> Dict:
    r"""
    **Autogenerated function**

     Deletes a resource policy that is identified by its resource ARN.

    Args:
        resource_arn(str):  The ARN of the resource that is associated with the resource policy. .

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.codebuild.resource_policy.delete(ctx, resource_arn=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.codebuild.resource_policy.delete resource_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="codebuild",
        operation="delete_resource_policy",
        op_kwargs={"resourceArn": resource_arn},
    )


async def get(hub, ctx, resource_arn: str) -> Dict:
    r"""
    **Autogenerated function**

     Gets a resource policy that is identified by its resource ARN.

    Args:
        resource_arn(str):  The ARN of the resource that is associated with the resource policy. .

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.codebuild.resource_policy.get(ctx, resource_arn=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.codebuild.resource_policy.get resource_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="codebuild",
        operation="get_resource_policy",
        op_kwargs={"resourceArn": resource_arn},
    )


async def put(hub, ctx, policy: str, resource_arn: str) -> Dict:
    r"""
    **Autogenerated function**

     Stores a resource policy for the ARN of a Project or ReportGroup object.

    Args:
        policy(str):  A JSON-formatted resource policy. For more information, see Sharing a Project and Sharing a Report Group in the AWS CodeBuild User Guide. .
        resource_arn(str):  The ARN of the Project or ReportGroup resource you want to associate with a resource policy. .

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.codebuild.resource_policy.put(
                ctx, policy=value, resource_arn=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.codebuild.resource_policy.put policy=value, resource_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="codebuild",
        operation="put_resource_policy",
        op_kwargs={"policy": policy, "resourceArn": resource_arn},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def disable(hub, ctx, cluster_identifier: str) -> Dict:
    r"""
    **Autogenerated function**

    Disables the automatic copying of snapshots from one region to another region for a specified cluster. If your cluster and its snapshots are encrypted using a customer master key (CMK) from Key Management Service, use DeleteSnapshotCopyGrant to delete the grant that grants Amazon Redshift permission to the CMK in the destination region.

    Args:
        cluster_identifier(str): The unique identifier of the source cluster that you want to disable copying of snapshots to a destination region. Constraints: Must be the valid name of an existing cluster that has cross-region snapshot copy enabled.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.redshift.snapshot.copy.init.disable(
                ctx, cluster_identifier=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.redshift.snapshot.copy.init.disable cluster_identifier=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="redshift",
        operation="disable_snapshot_copy",
        op_kwargs={"ClusterIdentifier": cluster_identifier},
    )


async def enable(
    hub,
    ctx,
    cluster_identifier: str,
    destination_region: str,
    retention_period: int = None,
    snapshot_copy_grant_name: str = None,
    manual_snapshot_retention_period: int = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Enables the automatic copy of snapshots from one region to another region for a specified cluster.

    Args:
        cluster_identifier(str): The unique identifier of the source cluster to copy snapshots from. Constraints: Must be the valid name of an existing cluster that does not already have cross-region snapshot copy enabled.
        destination_region(str): The destination Amazon Web Services Region that you want to copy snapshots to. Constraints: Must be the name of a valid Amazon Web Services Region. For more information, see Regions and Endpoints in the Amazon Web Services General Reference. .
        retention_period(int, optional): The number of days to retain automated snapshots in the destination region after they are copied from the source region. Default: 7. Constraints: Must be at least 1 and no more than 35. Defaults to None.
        snapshot_copy_grant_name(str, optional): The name of the snapshot copy grant to use when snapshots of an Amazon Web Services KMS-encrypted cluster are copied to the destination region. Defaults to None.
        manual_snapshot_retention_period(int, optional): The number of days to retain newly copied snapshots in the destination Amazon Web Services Region after they are copied from the source Amazon Web Services Region. If the value is -1, the manual snapshot is retained indefinitely.  The value must be either -1 or an integer between 1 and 3,653. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.redshift.snapshot.copy.init.enable(
                ctx, cluster_identifier=value, destination_region=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.redshift.snapshot.copy.init.enable cluster_identifier=value, destination_region=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="redshift",
        operation="enable_snapshot_copy",
        op_kwargs={
            "ClusterIdentifier": cluster_identifier,
            "DestinationRegion": destination_region,
            "RetentionPeriod": retention_period,
            "SnapshotCopyGrantName": snapshot_copy_grant_name,
            "ManualSnapshotRetentionPeriod": manual_snapshot_retention_period,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub,
    ctx,
    alias: str,
    directory_id: str = None,
    client_token: str = None,
    domains: List = None,
    kms_key_arn: str = None,
    enable_interoperability: bool = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a new Amazon WorkMail organization. Optionally, you can choose to associate an existing AWS Directory Service directory with your organization. If an AWS Directory Service directory ID is specified, the organization alias must match the directory alias. If you choose not to associate an existing directory with your organization, then we create a new Amazon WorkMail directory for you. For more information, see Adding an organization in the Amazon WorkMail Administrator Guide. You can associate multiple email domains with an organization, then set your default email domain from the Amazon WorkMail console. You can also associate a domain that is managed in an Amazon Route 53 public hosted zone. For more information, see Adding a domain and Choosing the default domain in the Amazon WorkMail Administrator Guide. Optionally, you can use a customer managed master key from AWS Key Management Service (AWS KMS) to encrypt email for your organization. If you don't associate an AWS KMS key, Amazon WorkMail creates a default AWS managed master key for you.

    Args:
        directory_id(str, optional): The AWS Directory Service directory ID. Defaults to None.
        alias(str): The organization alias.
        client_token(str, optional): The idempotency token associated with the request. Defaults to None.
        domains(List, optional): The email domains to associate with the organization. Defaults to None.
        kms_key_arn(str, optional): The Amazon Resource Name (ARN) of a customer managed master key from AWS KMS. Defaults to None.
        enable_interoperability(bool, optional): When true, allows organization interoperability between Amazon WorkMail and Microsoft Exchange. Can only be set to true if an AD Connector directory ID is included in the request. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.workmail.organization.create(ctx, alias=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.workmail.organization.create alias=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="workmail",
        operation="create_organization",
        op_kwargs={
            "DirectoryId": directory_id,
            "Alias": alias,
            "ClientToken": client_token,
            "Domains": domains,
            "KmsKeyArn": kms_key_arn,
            "EnableInteroperability": enable_interoperability,
        },
    )


async def delete(
    hub, ctx, organization_id: str, delete_directory: bool, client_token: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    Deletes an Amazon WorkMail organization and all underlying AWS resources managed by Amazon WorkMail as part of the organization. You can choose whether to delete the associated directory. For more information, see Removing an organization in the Amazon WorkMail Administrator Guide.

    Args:
        client_token(str, optional): The idempotency token associated with the request. Defaults to None.
        organization_id(str): The organization ID.
        delete_directory(bool): If true, deletes the AWS Directory Service directory associated with the organization.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.workmail.organization.delete(
                ctx, organization_id=value, delete_directory=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.workmail.organization.delete organization_id=value, delete_directory=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="workmail",
        operation="delete_organization",
        op_kwargs={
            "ClientToken": client_token,
            "OrganizationId": organization_id,
            "DeleteDirectory": delete_directory,
        },
    )


async def describe(hub, ctx, organization_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Provides more information regarding a given organization based on its identifier.

    Args:
        organization_id(str): The identifier for the organization to be described.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.workmail.organization.describe(ctx, organization_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.workmail.organization.describe organization_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="workmail",
        operation="describe_organization",
        op_kwargs={"OrganizationId": organization_id},
    )


async def list_all(hub, ctx, next_token: str = None, max_results: int = None) -> Dict:
    r"""
    **Autogenerated function**

    Returns summaries of the customer's organizations.

    Args:
        next_token(str, optional): The token to use to retrieve the next page of results. The first call does not contain any tokens. Defaults to None.
        max_results(int, optional): The maximum number of results to return in a single call. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.workmail.organization.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.workmail.organization.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="workmail",
        operation="list_organizations",
        op_kwargs={"NextToken": next_token, "MaxResults": max_results},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def send(
    hub, ctx, email_address: str, template_name: str, configuration_set_name: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    Adds an email address to the list of identities for your Amazon SES account in the current AWS Region and attempts to verify it. As a result of executing this operation, a customized verification email is sent to the specified address. To use this operation, you must first create a custom verification email template. For more information about creating and using custom verification email templates, see Using Custom Verification Email Templates in the Amazon SES Developer Guide. You can execute this operation no more than once per second.

    Args:
        email_address(str): The email address to verify.
        template_name(str): The name of the custom verification email template to use when sending the verification email.
        configuration_set_name(str, optional): Name of a configuration set to use when sending the verification email. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ses.custom_verification_email.init.send(
                ctx, email_address=value, template_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ses.custom_verification_email.init.send email_address=value, template_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ses",
        operation="send_custom_verification_email",
        op_kwargs={
            "EmailAddress": email_address,
            "TemplateName": template_name,
            "ConfigurationSetName": configuration_set_name,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def add(hub, ctx, gateway_arn: str, disk_ids: List) -> Dict:
    r"""
    **Autogenerated function**

    Configures one or more gateway local disks as upload buffer for a specified gateway. This operation is supported for the stored volume, cached volume, and tape gateway types. In the request, you specify the gateway Amazon Resource Name (ARN) to which you want to add upload buffer, and one or more disk IDs that you want to configure as upload buffer.

    Args:
        gateway_arn(str): The Amazon Resource Name (ARN) of the gateway. Use the ListGateways operation to return a list of gateways for your account and Region.
        disk_ids(List): An array of strings that identify disks that are to be configured as working storage. Each string has a minimum length of 1 and maximum length of 300. You can get the disk IDs from the ListLocalDisks API.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.storagegateway.upload_buffer.add(
                ctx, gateway_arn=value, disk_ids=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.storagegateway.upload_buffer.add gateway_arn=value, disk_ids=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="storagegateway",
        operation="add_upload_buffer",
        op_kwargs={"GatewayARN": gateway_arn, "DiskIds": disk_ids},
    )


async def describe(hub, ctx, gateway_arn: str) -> Dict:
    r"""
    **Autogenerated function**

    Returns information about the upload buffer of a gateway. This operation is supported for the stored volume, cached volume, and tape gateway types. The response includes disk IDs that are configured as upload buffer space, and it includes the amount of upload buffer space allocated and used.

    Args:
        gateway_arn(str): The Amazon Resource Name (ARN) of the gateway. Use the ListGateways operation to return a list of gateways for your account and Region.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.storagegateway.upload_buffer.describe(ctx, gateway_arn=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.storagegateway.upload_buffer.describe gateway_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="storagegateway",
        operation="describe_upload_buffer",
        op_kwargs={"GatewayARN": gateway_arn},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub,
    ctx,
    vpc_id: str,
    service_name: str,
    dry_run: bool = None,
    vpc_endpoint_type: str = None,
    policy_document: str = None,
    route_table_ids: List = None,
    subnet_ids: List = None,
    security_group_ids: List = None,
    client_token: str = None,
    private_dns_enabled: bool = None,
    tag_specifications: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a VPC endpoint for a specified service. An endpoint enables you to create a private connection between your VPC and the service. The service may be provided by AWS, an AWS Marketplace Partner, or another AWS account. For more information, see VPC Endpoints in the Amazon Virtual Private Cloud User Guide. A gateway endpoint serves as a target for a route in your route table for traffic destined for the AWS service. You can specify an endpoint policy to attach to the endpoint, which will control access to the service from your VPC. You can also specify the VPC route tables that use the endpoint. An interface endpoint is a network interface in your subnet that serves as an endpoint for communicating with the specified service. You can specify the subnets in which to create an endpoint, and the security groups to associate with the endpoint network interface. A GatewayLoadBalancer endpoint is a network interface in your subnet that serves an endpoint for communicating with a Gateway Load Balancer that you've configured as a VPC endpoint service. Use DescribeVpcEndpointServices to get a list of supported services.

    Args:
        dry_run(bool, optional): Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation. Defaults to None.
        vpc_endpoint_type(str, optional): The type of endpoint. Default: Gateway. Defaults to None.
        vpc_id(str): The ID of the VPC in which the endpoint will be used.
        service_name(str): The service name. To get a list of available services, use the DescribeVpcEndpointServices request, or get the name from the service provider.
        policy_document(str, optional): (Interface and gateway endpoints) A policy to attach to the endpoint that controls access to the service. The policy must be in valid JSON format. If this parameter is not specified, we attach a default policy that allows full access to the service. Defaults to None.
        route_table_ids(List, optional): (Gateway endpoint) One or more route table IDs. Defaults to None.
        subnet_ids(List, optional): (Interface and Gateway Load Balancer endpoints) The ID of one or more subnets in which to create an endpoint network interface. For a Gateway Load Balancer endpoint, you can specify one subnet only. Defaults to None.
        security_group_ids(List, optional): (Interface endpoint) The ID of one or more security groups to associate with the endpoint network interface. Defaults to None.
        client_token(str, optional): Unique, case-sensitive identifier that you provide to ensure the idempotency of the request. For more information, see How to Ensure Idempotency. Defaults to None.
        private_dns_enabled(bool, optional): (Interface endpoint) Indicates whether to associate a private hosted zone with the specified VPC. The private hosted zone contains a record set for the default public DNS name for the service for the Region (for example, kinesis.us-east-1.amazonaws.com), which resolves to the private IP addresses of the endpoint network interfaces in the VPC. This enables you to make requests to the default public DNS name for the service instead of the public DNS names that are automatically generated by the VPC endpoint service. To use a private hosted zone, you must set the following VPC attributes to true: enableDnsHostnames and enableDnsSupport. Use ModifyVpcAttribute to set the VPC attributes. Default: true . Defaults to None.
        tag_specifications(List, optional): The tags to associate with the endpoint. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ec2.vpc.endpoint.init.create(
                ctx, vpc_id=value, service_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ec2.vpc.endpoint.init.create vpc_id=value, service_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ec2",
        operation="create_vpc_endpoint",
        op_kwargs={
            "DryRun": dry_run,
            "VpcEndpointType": vpc_endpoint_type,
            "VpcId": vpc_id,
            "ServiceName": service_name,
            "PolicyDocument": policy_document,
            "RouteTableIds": route_table_ids,
            "SubnetIds": subnet_ids,
            "SecurityGroupIds": security_group_ids,
            "ClientToken": client_token,
            "PrivateDnsEnabled": private_dns_enabled,
            "TagSpecifications": tag_specifications,
        },
    )


async def delete_multiple(
    hub, ctx, vpc_endpoint_ids: List, dry_run: bool = None
) -> Dict:
    r"""
    **Autogenerated function**

    Deletes one or more specified VPC endpoints. You can delete any of the following types of VPC endpoints.    Gateway endpoint,   Gateway Load Balancer endpoint,   Interface endpoint   The following rules apply when you delete a VPC endpoint:   When you delete a gateway endpoint, we delete the endpoint routes in the route tables that are associated with the endpoint.   When you delete a Gateway Load Balancer endpoint, we delete the endpoint network interfaces.  You can only delete Gateway Load Balancer endpoints when the routes that are associated with the endpoint are deleted.   When you delete an interface endpoint, we delete the endpoint network interfaces.

    Args:
        dry_run(bool, optional): Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation. Defaults to None.
        vpc_endpoint_ids(List): One or more VPC endpoint IDs.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ec2.vpc.endpoint.init.delete_multiple(
                ctx, vpc_endpoint_ids=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ec2.vpc.endpoint.init.delete_multiple vpc_endpoint_ids=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ec2",
        operation="delete_vpc_endpoints",
        op_kwargs={"DryRun": dry_run, "VpcEndpointIds": vpc_endpoint_ids},
    )


async def describe_all(
    hub,
    ctx,
    dry_run: bool = None,
    vpc_endpoint_ids: List = None,
    filters: List = None,
    max_results: int = None,
    next_token: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Describes one or more of your VPC endpoints.

    Args:
        dry_run(bool, optional): Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation. Defaults to None.
        vpc_endpoint_ids(List, optional): One or more endpoint IDs. Defaults to None.
        filters(List, optional): One or more filters.    service-name - The name of the service.    vpc-id - The ID of the VPC in which the endpoint resides.    vpc-endpoint-id - The ID of the endpoint.    vpc-endpoint-state - The state of the endpoint (pendingAcceptance | pending | available | deleting | deleted | rejected | failed).    vpc-endpoint-type - The type of VPC endpoint (Interface | Gateway | GatewayLoadBalancer).    tag:<key> - The key/value combination of a tag assigned to the resource. Use the tag key in the filter name and the tag value as the filter value. For example, to find all resources that have a tag with the key Owner and the value TeamA, specify tag:Owner for the filter name and TeamA for the filter value.    tag-key - The key of a tag assigned to the resource. Use this filter to find all resources assigned a tag with a specific key, regardless of the tag value.  . Defaults to None.
        max_results(int, optional): The maximum number of items to return for this request. The request returns a token that you can specify in a subsequent call to get the next set of results. Constraint: If the value is greater than 1,000, we return only 1,000 items. Defaults to None.
        next_token(str, optional): The token for the next set of items to return. (You received this token from a prior call.). Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ec2.vpc.endpoint.init.describe_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ec2.vpc.endpoint.init.describe_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ec2",
        operation="describe_vpc_endpoints",
        op_kwargs={
            "DryRun": dry_run,
            "VpcEndpointIds": vpc_endpoint_ids,
            "Filters": filters,
            "MaxResults": max_results,
            "NextToken": next_token,
        },
    )


async def modify(
    hub,
    ctx,
    vpc_endpoint_id: str,
    dry_run: bool = None,
    reset_policy: bool = None,
    policy_document: str = None,
    add_route_table_ids: List = None,
    remove_route_table_ids: List = None,
    add_subnet_ids: List = None,
    remove_subnet_ids: List = None,
    add_security_group_ids: List = None,
    remove_security_group_ids: List = None,
    private_dns_enabled: bool = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Modifies attributes of a specified VPC endpoint. The attributes that you can modify depend on the type of VPC endpoint (interface, gateway, or Gateway Load Balancer). For more information, see VPC Endpoints in the Amazon Virtual Private Cloud User Guide.

    Args:
        dry_run(bool, optional): Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation. Defaults to None.
        vpc_endpoint_id(str): The ID of the endpoint.
        reset_policy(bool, optional): (Gateway endpoint) Specify true to reset the policy document to the default policy. The default policy allows full access to the service. Defaults to None.
        policy_document(str, optional): (Interface and gateway endpoints) A policy to attach to the endpoint that controls access to the service. The policy must be in valid JSON format. Defaults to None.
        add_route_table_ids(List, optional): (Gateway endpoint) One or more route tables IDs to associate with the endpoint. Defaults to None.
        remove_route_table_ids(List, optional): (Gateway endpoint) One or more route table IDs to disassociate from the endpoint. Defaults to None.
        add_subnet_ids(List, optional): (Interface and Gateway Load Balancer endpoints) One or more subnet IDs in which to serve the endpoint. For a Gateway Load Balancer endpoint, you can specify only one subnet. Defaults to None.
        remove_subnet_ids(List, optional): (Interface endpoint) One or more subnets IDs in which to remove the endpoint. Defaults to None.
        add_security_group_ids(List, optional): (Interface endpoint) One or more security group IDs to associate with the network interface. Defaults to None.
        remove_security_group_ids(List, optional): (Interface endpoint) One or more security group IDs to disassociate from the network interface. Defaults to None.
        private_dns_enabled(bool, optional): (Interface endpoint) Indicates whether a private hosted zone is associated with the VPC. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ec2.vpc.endpoint.init.modify(ctx, vpc_endpoint_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ec2.vpc.endpoint.init.modify vpc_endpoint_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ec2",
        operation="modify_vpc_endpoint",
        op_kwargs={
            "DryRun": dry_run,
            "VpcEndpointId": vpc_endpoint_id,
            "ResetPolicy": reset_policy,
            "PolicyDocument": policy_document,
            "AddRouteTableIds": add_route_table_ids,
            "RemoveRouteTableIds": remove_route_table_ids,
            "AddSubnetIds": add_subnet_ids,
            "RemoveSubnetIds": remove_subnet_ids,
            "AddSecurityGroupIds": add_security_group_ids,
            "RemoveSecurityGroupIds": remove_security_group_ids,
            "PrivateDnsEnabled": private_dns_enabled,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def associate(hub, ctx, emergency_contact_list: List) -> Dict:
    r"""
    **Autogenerated function**

    Initializes proactive engagement and sets the list of contacts for the Shield Response Team (SRT) to use. You must provide at least one phone number in the emergency contact list.  After you have initialized proactive engagement using this call, to disable or enable proactive engagement, use the calls DisableProactiveEngagement and EnableProactiveEngagement.   This call defines the list of email addresses and phone numbers that the SRT can use to contact you for escalations to the SRT and to initiate proactive customer support. The contacts that you provide in the request replace any contacts that were already defined. If you already have contacts defined and want to use them, retrieve the list using DescribeEmergencyContactSettings and then provide it to this call.

    Args:
        emergency_contact_list(List): A list of email addresses and phone numbers that the Shield Response Team (SRT) can use to contact you for escalations to the SRT and to initiate proactive customer support.  To enable proactive engagement, the contact list must include at least one phone number.  The contacts that you provide here replace any contacts that were already defined. If you already have contacts defined and want to use them, retrieve the list using DescribeEmergencyContactSettings and then provide it here.  .

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.shield.proactive_engagement.detail.associate(
                ctx, emergency_contact_list=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.shield.proactive_engagement.detail.associate emergency_contact_list=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="shield",
        operation="associate_proactive_engagement_details",
        op_kwargs={"EmergencyContactList": emergency_contact_list},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def generate(
    hub,
    ctx,
    key_id: str,
    key_pair_spec: str,
    encryption_context: Dict = None,
    grant_tokens: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Generates a unique asymmetric data key pair. The GenerateDataKeyPair operation returns a plaintext public key, a plaintext private key, and a copy of the private key that is encrypted under the symmetric CMK you specify. You can use the data key pair to perform asymmetric cryptography outside of AWS KMS.  GenerateDataKeyPair returns a unique data key pair for each request. The bytes in the keys are not related to the caller or the CMK that is used to encrypt the private key. You can use the public key that GenerateDataKeyPair returns to encrypt data or verify a signature outside of AWS KMS. Then, store the encrypted private key with the data. When you are ready to decrypt data or sign a message, you can use the Decrypt operation to decrypt the encrypted private key. To generate a data key pair, you must specify a symmetric customer master key (CMK) to encrypt the private key in a data key pair. You cannot use an asymmetric CMK or a CMK in a custom key store. To get the type and origin of your CMK, use the DescribeKey operation.  If you are using the data key pair to encrypt data, or for any operation where you don't immediately need a private key, consider using the GenerateDataKeyPairWithoutPlaintext operation. GenerateDataKeyPairWithoutPlaintext returns a plaintext public key and an encrypted private key, but omits the plaintext private key that you need only to decrypt ciphertext or sign a message. Later, when you need to decrypt the data or sign a message, use the Decrypt operation to decrypt the encrypted private key in the data key pair. You can use the optional encryption context to add additional security to the encryption operation. If you specify an EncryptionContext, you must specify the same encryption context (a case-sensitive exact match) when decrypting the encrypted data key. Otherwise, the request to decrypt fails with an InvalidCiphertextException. For more information, see Encryption Context in the AWS Key Management Service Developer Guide. The CMK that you use for this operation must be in a compatible key state. For details, see Key state: Effect on your CMK in the AWS Key Management Service Developer Guide.  Cross-account use: Yes. To perform this operation with a CMK in a different AWS account, specify the key ARN or alias ARN in the value of the KeyId parameter.  Required permissions: kms:GenerateDataKeyPair (key policy)  Related operations:     Decrypt     Encrypt     GenerateDataKey     GenerateDataKeyPairWithoutPlaintext     GenerateDataKeyWithoutPlaintext

    Args:
        encryption_context(Dict, optional): Specifies the encryption context that will be used when encrypting the private key in the data key pair. An encryption context is a collection of non-secret key-value pairs that represents additional authenticated data. When you use an encryption context to encrypt data, you must specify the same (an exact case-sensitive match) encryption context to decrypt the data. An encryption context is optional when encrypting with a symmetric CMK, but it is highly recommended. For more information, see Encryption Context in the AWS Key Management Service Developer Guide. Defaults to None.
        key_id(str): Specifies the symmetric CMK that encrypts the private key in the data key pair. You cannot specify an asymmetric CMK or a CMK in a custom key store. To get the type and origin of your CMK, use the DescribeKey operation. To specify a CMK, use its key ID, key ARN, alias name, or alias ARN. When using an alias name, prefix it with "alias/". To specify a CMK in a different AWS account, you must use the key ARN or alias ARN. For example:   Key ID: 1234abcd-12ab-34cd-56ef-1234567890ab    Key ARN: arn:aws:kms:us-east-2:111122223333:key/1234abcd-12ab-34cd-56ef-1234567890ab    Alias name: alias/ExampleAlias    Alias ARN: arn:aws:kms:us-east-2:111122223333:alias/ExampleAlias    To get the key ID and key ARN for a CMK, use ListKeys or DescribeKey. To get the alias name and alias ARN, use ListAliases.
        key_pair_spec(str): Determines the type of data key pair that is generated.  The AWS KMS rule that restricts the use of asymmetric RSA CMKs to encrypt and decrypt or to sign and verify (but not both), and the rule that permits you to use ECC CMKs only to sign and verify, are not effective outside of AWS KMS.
        grant_tokens(List, optional): A list of grant tokens. Use a grant token when your permission to call this operation comes from a new grant that has not yet achieved eventual consistency. For more information, see Grant token in the AWS Key Management Service Developer Guide. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.kms.data_key.pair.init.generate(
                ctx, key_id=value, key_pair_spec=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.kms.data_key.pair.init.generate key_id=value, key_pair_spec=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="kms",
        operation="generate_data_key_pair",
        op_kwargs={
            "EncryptionContext": encryption_context,
            "KeyId": key_id,
            "KeyPairSpec": key_pair_spec,
            "GrantTokens": grant_tokens,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub,
    ctx,
    availability_zones: List,
    multiplex_settings: Dict,
    name: str,
    request_id: str,
    tags: Dict = None,
) -> Dict:
    r"""
        **Autogenerated function**

        Create a new multiplex.

        Args:
            availability_zones(List): A list of availability zones for the multiplex. You must specify exactly two.
            multiplex_settings(Dict): Configuration for a multiplex event.
            name(str): Name of multiplex.
            request_id(str): Unique request ID. This prevents retries from creating multiple
    resources.
    .
            tags(Dict, optional): A collection of key-value pairs. Defaults to None.

        Returns:
            Dict

        Examples:
            Call from code:

            .. code-block:: python

                await hub.exec.aws_auto.medialive.multiplex.init.create(
                    ctx,
                    availability_zones=value,
                    multiplex_settings=value,
                    name=value,
                    request_id=value,
                )

            Call from CLI:

            .. code-block:: bash

                $ idem exec aws_auto.medialive.multiplex.init.create availability_zones=value, multiplex_settings=value, name=value, request_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="medialive",
        operation="create_multiplex",
        op_kwargs={
            "AvailabilityZones": availability_zones,
            "MultiplexSettings": multiplex_settings,
            "Name": name,
            "RequestId": request_id,
            "Tags": tags,
        },
    )


async def delete(hub, ctx, multiplex_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Delete a multiplex. The multiplex must be idle.

    Args:
        multiplex_id(str): The ID of the multiplex.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.medialive.multiplex.init.delete(ctx, multiplex_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.medialive.multiplex.init.delete multiplex_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="medialive",
        operation="delete_multiplex",
        op_kwargs={"MultiplexId": multiplex_id},
    )


async def describe(hub, ctx, multiplex_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Gets details about a multiplex.

    Args:
        multiplex_id(str): The ID of the multiplex.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.medialive.multiplex.init.describe(ctx, multiplex_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.medialive.multiplex.init.describe multiplex_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="medialive",
        operation="describe_multiplex",
        op_kwargs={"MultiplexId": multiplex_id},
    )


async def list_all(hub, ctx, max_results: int = None, next_token: str = None) -> Dict:
    r"""
    **Autogenerated function**

    Retrieve a list of the existing multiplexes.

    Args:
        max_results(int, optional): The maximum number of items to return. Defaults to None.
        next_token(str, optional): The token to retrieve the next page of results. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.medialive.multiplex.init.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.medialive.multiplex.init.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="medialive",
        operation="list_multiplexes",
        op_kwargs={"MaxResults": max_results, "NextToken": next_token},
    )


async def start(hub, ctx, multiplex_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Start (run) the multiplex. Starting the multiplex does not start the channels. You must explicitly start each channel.

    Args:
        multiplex_id(str): The ID of the multiplex.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.medialive.multiplex.init.start(ctx, multiplex_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.medialive.multiplex.init.start multiplex_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="medialive",
        operation="start_multiplex",
        op_kwargs={"MultiplexId": multiplex_id},
    )


async def stop(hub, ctx, multiplex_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Stops a running multiplex. If the multiplex isn't running, this action has no effect.

    Args:
        multiplex_id(str): The ID of the multiplex.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.medialive.multiplex.init.stop(ctx, multiplex_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.medialive.multiplex.init.stop multiplex_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="medialive",
        operation="stop_multiplex",
        op_kwargs={"MultiplexId": multiplex_id},
    )


async def update(
    hub, ctx, multiplex_id: str, multiplex_settings: Dict = None, name: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    Updates a multiplex.

    Args:
        multiplex_id(str): ID of the multiplex to update.
        multiplex_settings(Dict, optional): The new settings for a multiplex. Defaults to None.
        name(str, optional): Name of the multiplex. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.medialive.multiplex.init.update(ctx, multiplex_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.medialive.multiplex.init.update multiplex_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="medialive",
        operation="update_multiplex",
        op_kwargs={
            "MultiplexId": multiplex_id,
            "MultiplexSettings": multiplex_settings,
            "Name": name,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""


async def update(hub, ctx, service_id: str, instance_id: str, status: str) -> None:
    r"""
    **Autogenerated function**

    Submits a request to change the health status of a custom health check to healthy or unhealthy. You can use UpdateInstanceCustomHealthStatus to change the status only for custom health checks, which you define using HealthCheckCustomConfig when you create a service. You can't use it to change the status for Route 53 health checks, which you define using HealthCheckConfig. For more information, see HealthCheckCustomConfig.

    Args:
        service_id(str): The ID of the service that includes the configuration for the custom health check that you want to change the status for.
        instance_id(str): The ID of the instance that you want to change the health status for.
        status(str): The new status of the instance, HEALTHY or UNHEALTHY.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.servicediscovery.instance.custom_health_status.update(
                ctx, service_id=value, instance_id=value, status=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.servicediscovery.instance.custom_health_status.update service_id=value, instance_id=value, status=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="servicediscovery",
        operation="update_instance_custom_health_status",
        op_kwargs={
            "ServiceId": service_id,
            "InstanceId": instance_id,
            "Status": status,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def get_all(hub, ctx, sampling_statistics_documents: List) -> Dict:
    r"""
    **Autogenerated function**

    Requests a sampling quota for rules that the service is using to sample requests.

    Args:
        sampling_statistics_documents(List): Information about rules that the service is using to sample requests.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.xray.sampling.target.get_all(
                ctx, sampling_statistics_documents=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.xray.sampling.target.get_all sampling_statistics_documents=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="xray",
        operation="get_sampling_targets",
        op_kwargs={"SamplingStatisticsDocuments": sampling_statistics_documents},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def describe_all(
    hub,
    ctx,
    application_name: str,
    template_name: str = None,
    environment_name: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Returns a description of the settings for the specified configuration set, that is, either a configuration template or the configuration set associated with a running environment. When describing the settings for the configuration set associated with a running environment, it is possible to receive two sets of setting descriptions. One is the deployed configuration set, and the other is a draft configuration of an environment that is either in the process of deployment or that failed to deploy. Related Topics    DeleteEnvironmentConfiguration

    Args:
        application_name(str): The application for the environment or configuration template.
        template_name(str, optional): The name of the configuration template to describe.  Conditional: You must specify either this parameter or an EnvironmentName, but not both. If you specify both, AWS Elastic Beanstalk returns an InvalidParameterCombination error. If you do not specify either, AWS Elastic Beanstalk returns a MissingRequiredParameter error. . Defaults to None.
        environment_name(str, optional): The name of the environment to describe.  Condition: You must specify either this or a TemplateName, but not both. If you specify both, AWS Elastic Beanstalk returns an InvalidParameterCombination error. If you do not specify either, AWS Elastic Beanstalk returns MissingRequiredParameter error. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.elasticbeanstalk.configuration.setting.describe_all(
                ctx, application_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.elasticbeanstalk.configuration.setting.describe_all application_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="elasticbeanstalk",
        operation="describe_configuration_settings",
        op_kwargs={
            "ApplicationName": application_name,
            "TemplateName": template_name,
            "EnvironmentName": environment_name,
        },
    )


async def validate(
    hub,
    ctx,
    application_name: str,
    option_settings: List,
    template_name: str = None,
    environment_name: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Takes a set of configuration settings and either a configuration template or environment, and determines whether those values are valid. This action returns a list of messages indicating any errors or warnings associated with the selection of option values.

    Args:
        application_name(str): The name of the application that the configuration template or environment belongs to.
        template_name(str, optional): The name of the configuration template to validate the settings against. Condition: You cannot specify both this and an environment name. Defaults to None.
        environment_name(str, optional): The name of the environment to validate the settings against. Condition: You cannot specify both this and a configuration template name. Defaults to None.
        option_settings(List): A list of the options and desired values to evaluate.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.elasticbeanstalk.configuration.setting.validate(
                ctx, application_name=value, option_settings=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.elasticbeanstalk.configuration.setting.validate application_name=value, option_settings=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="elasticbeanstalk",
        operation="validate_configuration_settings",
        op_kwargs={
            "ApplicationName": application_name,
            "TemplateName": template_name,
            "EnvironmentName": environment_name,
            "OptionSettings": option_settings,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def update(
    hub, ctx, fleet_arn: str, domain_name: str, display_name: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    Updates domain metadata, such as DisplayName.

    Args:
        fleet_arn(str): The ARN of the fleet.
        domain_name(str): The name of the domain.
        display_name(str, optional): The name to display. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.worklink.domain.metadata.update(
                ctx, fleet_arn=value, domain_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.worklink.domain.metadata.update fleet_arn=value, domain_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="worklink",
        operation="update_domain_metadata",
        op_kwargs={
            "FleetArn": fleet_arn,
            "DomainName": domain_name,
            "DisplayName": display_name,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def create(
    hub,
    ctx,
    name: str,
    role: str,
    command: Dict,
    description: str = None,
    log_uri: str = None,
    execution_property: Dict = None,
    default_arguments: Dict = None,
    non_overridable_arguments: Dict = None,
    connections: Dict = None,
    max_retries: int = None,
    allocated_capacity: int = None,
    timeout: int = None,
    max_capacity: float = None,
    security_configuration: str = None,
    tags: Dict = None,
    notification_property: Dict = None,
    glue_version: str = None,
    number_of_workers: int = None,
    worker_type: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a new job definition.

    Args:
        name(str): The name you assign to this job definition. It must be unique in your account.
        description(str, optional): Description of the job being defined. Defaults to None.
        log_uri(str, optional): This field is reserved for future use. Defaults to None.
        role(str): The name or Amazon Resource Name (ARN) of the IAM role associated with this job.
        execution_property(Dict, optional): An ExecutionProperty specifying the maximum number of concurrent runs allowed for this job. Defaults to None.
        command(Dict): The JobCommand that runs this job.
        default_arguments(Dict, optional): The default arguments for this job. You can specify arguments here that your own job-execution script consumes, as well as arguments that Glue itself consumes. For information about how to specify and consume your own Job arguments, see the Calling Glue APIs in Python topic in the developer guide. For information about the key-value pairs that Glue consumes to set up your job, see the Special Parameters Used by Glue topic in the developer guide. Defaults to None.
        non_overridable_arguments(Dict, optional): Non-overridable arguments for this job, specified as name-value pairs. Defaults to None.
        connections(Dict, optional): The connections used for this job. Defaults to None.
        max_retries(int, optional): The maximum number of times to retry this job if it fails. Defaults to None.
        allocated_capacity(int, optional): This parameter is deprecated. Use MaxCapacity instead. The number of Glue data processing units (DPUs) to allocate to this Job. You can allocate from 2 to 100 DPUs; the default is 10. A DPU is a relative measure of processing power that consists of 4 vCPUs of compute capacity and 16 GB of memory. For more information, see the Glue pricing page. Defaults to None.
        timeout(int, optional): The job timeout in minutes. This is the maximum time that a job run can consume resources before it is terminated and enters TIMEOUT status. The default is 2,880 minutes (48 hours). Defaults to None.
        max_capacity(float, optional): For Glue version 1.0 or earlier jobs, using the standard worker type, the number of Glue data processing units (DPUs) that can be allocated when this job runs. A DPU is a relative measure of processing power that consists of 4 vCPUs of compute capacity and 16 GB of memory. For more information, see the Glue pricing page. Do not set Max Capacity if using WorkerType and NumberOfWorkers. The value that can be allocated for MaxCapacity depends on whether you are running a Python shell job or an Apache Spark ETL job:   When you specify a Python shell job (JobCommand.Name="pythonshell"), you can allocate either 0.0625 or 1 DPU. The default is 0.0625 DPU.   When you specify an Apache Spark ETL job (JobCommand.Name="glueetl") or Apache Spark streaming ETL job (JobCommand.Name="gluestreaming"), you can allocate from 2 to 100 DPUs. The default is 10 DPUs. This job type cannot have a fractional DPU allocation.   For Glue version 2.0 jobs, you cannot instead specify a Maximum capacity. Instead, you should specify a Worker type and the Number of workers. Defaults to None.
        security_configuration(str, optional): The name of the SecurityConfiguration structure to be used with this job. Defaults to None.
        tags(Dict, optional): The tags to use with this job. You may use tags to limit access to the job. For more information about tags in Glue, see Amazon Web Services Tags in Glue in the developer guide. Defaults to None.
        notification_property(Dict, optional): Specifies configuration properties of a job notification. Defaults to None.
        glue_version(str, optional): Glue version determines the versions of Apache Spark and Python that Glue supports. The Python version indicates the version supported for jobs of type Spark.  For more information about the available Glue versions and corresponding Spark and Python versions, see Glue version in the developer guide. Jobs that are created without specifying a Glue version default to Glue 0.9. Defaults to None.
        number_of_workers(int, optional): The number of workers of a defined workerType that are allocated when a job runs. The maximum number of workers you can define are 299 for G.1X, and 149 for G.2X. . Defaults to None.
        worker_type(str, optional): The type of predefined worker that is allocated when a job runs. Accepts a value of Standard, G.1X, or G.2X.   For the Standard worker type, each worker provides 4 vCPU, 16 GB of memory and a 50GB disk, and 2 executors per worker.   For the G.1X worker type, each worker maps to 1 DPU (4 vCPU, 16 GB of memory, 64 GB disk), and provides 1 executor per worker. We recommend this worker type for memory-intensive jobs.   For the G.2X worker type, each worker maps to 2 DPU (8 vCPU, 32 GB of memory, 128 GB disk), and provides 1 executor per worker. We recommend this worker type for memory-intensive jobs.  . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.glue.job.init.create(ctx, name=value, role=value, command=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.glue.job.init.create name=value, role=value, command=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="glue",
        operation="create_job",
        op_kwargs={
            "Name": name,
            "Description": description,
            "LogUri": log_uri,
            "Role": role,
            "ExecutionProperty": execution_property,
            "Command": command,
            "DefaultArguments": default_arguments,
            "NonOverridableArguments": non_overridable_arguments,
            "Connections": connections,
            "MaxRetries": max_retries,
            "AllocatedCapacity": allocated_capacity,
            "Timeout": timeout,
            "MaxCapacity": max_capacity,
            "SecurityConfiguration": security_configuration,
            "Tags": tags,
            "NotificationProperty": notification_property,
            "GlueVersion": glue_version,
            "NumberOfWorkers": number_of_workers,
            "WorkerType": worker_type,
        },
    )


async def delete(hub, ctx, job_name: str) -> Dict:
    r"""
    **Autogenerated function**

    Deletes a specified job definition. If the job definition is not found, no exception is thrown.

    Args:
        job_name(str): The name of the job definition to delete.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.glue.job.init.delete(ctx, job_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.glue.job.init.delete job_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="glue",
        operation="delete_job",
        op_kwargs={"JobName": job_name},
    )


async def get(hub, ctx, job_name: str) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves an existing job definition.

    Args:
        job_name(str): The name of the job definition to retrieve.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.glue.job.init.get(ctx, job_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.glue.job.init.get job_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx, service_name="glue", operation="get_job", op_kwargs={"JobName": job_name}
    )


async def update(hub, ctx, job_name: str, job_update: Dict) -> Dict:
    r"""
    **Autogenerated function**

    Updates an existing job definition.

    Args:
        job_name(str): The name of the job definition to update.
        job_update(Dict): Specifies the values with which to update the job definition.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.glue.job.init.update(ctx, job_name=value, job_update=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.glue.job.init.update job_name=value, job_update=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="glue",
        operation="update_job",
        op_kwargs={"JobName": job_name, "JobUpdate": job_update},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def modify(
    hub,
    ctx,
    vpn_connection_id: str,
    vpn_tunnel_outside_ip_address: str,
    dry_run: bool = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Modifies the VPN tunnel endpoint certificate.

    Args:
        vpn_connection_id(str): The ID of the AWS Site-to-Site VPN connection.
        vpn_tunnel_outside_ip_address(str): The external IP address of the VPN tunnel.
        dry_run(bool, optional): Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ec2.vpn.tunnel.certificate.modify(
                ctx, vpn_connection_id=value, vpn_tunnel_outside_ip_address=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ec2.vpn.tunnel.certificate.modify vpn_connection_id=value, vpn_tunnel_outside_ip_address=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ec2",
        operation="modify_vpn_tunnel_certificate",
        op_kwargs={
            "VpnConnectionId": vpn_connection_id,
            "VpnTunnelOutsideIpAddress": vpn_tunnel_outside_ip_address,
            "DryRun": dry_run,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def create(hub, ctx, solution_arn: str, training_mode: str = None) -> Dict:
    r"""
    **Autogenerated function**

    Trains or retrains an active solution. A solution is created using the CreateSolution operation and must be in the ACTIVE state before calling CreateSolutionVersion. A new version of the solution is created every time you call this operation.  Status  A solution version can be in one of the following states:   CREATE PENDING   CREATE IN_PROGRESS   ACTIVE   CREATE FAILED   CREATE STOPPING   CREATE STOPPED   To get the status of the version, call DescribeSolutionVersion. Wait until the status shows as ACTIVE before calling CreateCampaign. If the status shows as CREATE FAILED, the response includes a failureReason key, which describes why the job failed.  Related APIs     ListSolutionVersions     DescribeSolutionVersion       ListSolutions     CreateSolution     DescribeSolution     DeleteSolution

    Args:
        solution_arn(str): The Amazon Resource Name (ARN) of the solution containing the training configuration information.
        training_mode(str, optional): The scope of training to be performed when creating the solution version. The FULL option trains the solution version based on the entirety of the input solution's training data, while the UPDATE option processes only the data that has changed in comparison to the input solution. Choose UPDATE when you want to incrementally update your solution version instead of creating an entirely new one.  The UPDATE option can only be used when you already have an active solution version created from the input solution using the FULL option and the input solution was trained with the User-Personalization recipe or the HRNN-Coldstart recipe. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.personalize.solution.version.init.create(
                ctx, solution_arn=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.personalize.solution.version.init.create solution_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="personalize",
        operation="create_solution_version",
        op_kwargs={"solutionArn": solution_arn, "trainingMode": training_mode},
    )


async def describe(hub, ctx, solution_version_arn: str) -> Dict:
    r"""
    **Autogenerated function**

    Describes a specific version of a solution. For more information on solutions, see CreateSolution.

    Args:
        solution_version_arn(str): The Amazon Resource Name (ARN) of the solution version.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.personalize.solution.version.init.describe(
                ctx, solution_version_arn=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.personalize.solution.version.init.describe solution_version_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="personalize",
        operation="describe_solution_version",
        op_kwargs={"solutionVersionArn": solution_version_arn},
    )


async def list_all(
    hub, ctx, solution_arn: str = None, next_token: str = None, max_results: int = None
) -> Dict:
    r"""
    **Autogenerated function**

    Returns a list of solution versions for the given solution. When a solution is not specified, all the solution versions associated with the account are listed. The response provides the properties for each solution version, including the Amazon Resource Name (ARN). For more information on solutions, see CreateSolution.

    Args:
        solution_arn(str, optional): The Amazon Resource Name (ARN) of the solution. Defaults to None.
        next_token(str, optional): A token returned from the previous call to ListSolutionVersions for getting the next set of solution versions (if they exist). Defaults to None.
        max_results(int, optional): The maximum number of solution versions to return. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.personalize.solution.version.init.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.personalize.solution.version.init.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="personalize",
        operation="list_solution_versions",
        op_kwargs={
            "solutionArn": solution_arn,
            "nextToken": next_token,
            "maxResults": max_results,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def get(
    hub,
    ctx,
    scaling_plan_name: str,
    scaling_plan_version: int,
    service_namespace: str,
    resource_id: str,
    scalable_dimension: str,
    forecast_data_type: str,
    start_time: str,
    end_time: str,
) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves the forecast data for a scalable resource. Capacity forecasts are represented as predicted values, or data points, that are calculated using historical data points from a specified CloudWatch load metric. Data points are available for up to 56 days.

    Args:
        scaling_plan_name(str): The name of the scaling plan.
        scaling_plan_version(int): The version number of the scaling plan. Currently, the only valid value is 1.
        service_namespace(str): The namespace of the AWS service. The only valid value is autoscaling. .
        resource_id(str): The ID of the resource. This string consists of a prefix (autoScalingGroup) followed by the name of a specified Auto Scaling group (my-asg). Example: autoScalingGroup/my-asg. .
        scalable_dimension(str): The scalable dimension for the resource. The only valid value is autoscaling:autoScalingGroup:DesiredCapacity. .
        forecast_data_type(str): The type of forecast data to get.    LoadForecast: The load metric forecast.     CapacityForecast: The capacity forecast.     ScheduledActionMinCapacity: The minimum capacity for each scheduled scaling action. This data is calculated as the larger of two values: the capacity forecast or the minimum capacity in the scaling instruction.    ScheduledActionMaxCapacity: The maximum capacity for each scheduled scaling action. The calculation used is determined by the predictive scaling maximum capacity behavior setting in the scaling instruction.  .
        start_time(str): The inclusive start time of the time range for the forecast data to get. The date and time can be at most 56 days before the current date and time. .
        end_time(str): The exclusive end time of the time range for the forecast data to get. The maximum time duration between the start and end time is seven days.  Although this parameter can accept a date and time that is more than two days in the future, the availability of forecast data has limits. AWS Auto Scaling only issues forecasts for periods of two days in advance.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.autoscaling_plan_scaling_plan.resource.forecast_data.get(
                ctx,
                scaling_plan_name=value,
                scaling_plan_version=value,
                service_namespace=value,
                resource_id=value,
                scalable_dimension=value,
                forecast_data_type=value,
                start_time=value,
                end_time=value,
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.autoscaling_plan_scaling_plan.resource.forecast_data.get scaling_plan_name=value, scaling_plan_version=value, service_namespace=value, resource_id=value, scalable_dimension=value, forecast_data_type=value, start_time=value, end_time=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="autoscaling-plans",
        operation="get_scaling_plan_resource_forecast_data",
        op_kwargs={
            "ScalingPlanName": scaling_plan_name,
            "ScalingPlanVersion": scaling_plan_version,
            "ServiceNamespace": service_namespace,
            "ResourceId": resource_id,
            "ScalableDimension": scalable_dimension,
            "ForecastDataType": forecast_data_type,
            "StartTime": start_time,
            "EndTime": end_time,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def create(
    hub,
    ctx,
    http_configuration: Dict,
    source_location_name: str,
    access_configuration: Dict = None,
    default_segment_delivery_configuration: Dict = None,
    tags: Dict = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a source location on a specific channel.

    Args:
        access_configuration(Dict, optional): Access configuration parameters. Configures the type of authentication used to access content from your source location. Defaults to None.
        default_segment_delivery_configuration(Dict, optional): The optional configuration for the server that serves segments. Defaults to None.
        http_configuration(Dict): The source's HTTP package configurations.
        source_location_name(str): The identifier for the source location you are working on.
        tags(Dict, optional): The tags to assign to the source location. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.mediatailor.source_location.create(
                ctx, http_configuration=value, source_location_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.mediatailor.source_location.create http_configuration=value, source_location_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="mediatailor",
        operation="create_source_location",
        op_kwargs={
            "AccessConfiguration": access_configuration,
            "DefaultSegmentDeliveryConfiguration": default_segment_delivery_configuration,
            "HttpConfiguration": http_configuration,
            "SourceLocationName": source_location_name,
            "Tags": tags,
        },
    )


async def delete(hub, ctx, source_location_name: str) -> Dict:
    r"""
    **Autogenerated function**

    Deletes a source location on a specific channel.

    Args:
        source_location_name(str): The identifier for the source location you are working on.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.mediatailor.source_location.delete(
                ctx, source_location_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.mediatailor.source_location.delete source_location_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="mediatailor",
        operation="delete_source_location",
        op_kwargs={"SourceLocationName": source_location_name},
    )


async def describe(hub, ctx, source_location_name: str) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves the properties of the requested source location.

    Args:
        source_location_name(str): The identifier for the source location you are working on.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.mediatailor.source_location.describe(
                ctx, source_location_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.mediatailor.source_location.describe source_location_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="mediatailor",
        operation="describe_source_location",
        op_kwargs={"SourceLocationName": source_location_name},
    )


async def list_all(hub, ctx, max_results: int = None, next_token: str = None) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves a list of source locations.

    Args:
        max_results(int, optional): Upper bound on number of records to return. The maximum number of results is 100. Defaults to None.
        next_token(str, optional): Pagination token from the GET list request. Use the token to fetch the next page of results. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.mediatailor.source_location.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.mediatailor.source_location.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="mediatailor",
        operation="list_source_locations",
        op_kwargs={"MaxResults": max_results, "NextToken": next_token},
    )


async def update(
    hub,
    ctx,
    http_configuration: Dict,
    source_location_name: str,
    access_configuration: Dict = None,
    default_segment_delivery_configuration: Dict = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Updates a source location on a specific channel.

    Args:
        access_configuration(Dict, optional): Access configuration parameters. Configures the type of authentication used to access content from your source location. Defaults to None.
        default_segment_delivery_configuration(Dict, optional): The optional configuration for the host server that serves segments. Defaults to None.
        http_configuration(Dict): The HTTP configuration for the source location.
        source_location_name(str): The identifier for the source location you are working on.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.mediatailor.source_location.update(
                ctx, http_configuration=value, source_location_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.mediatailor.source_location.update http_configuration=value, source_location_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="mediatailor",
        operation="update_source_location",
        op_kwargs={
            "AccessConfiguration": access_configuration,
            "DefaultSegmentDeliveryConfiguration": default_segment_delivery_configuration,
            "HttpConfiguration": http_configuration,
            "SourceLocationName": source_location_name,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def delete(hub, ctx, email_address: str) -> Dict:
    r"""
    **Autogenerated function**

    Removes an email address from the suppression list for your account.

    Args:
        email_address(str): The suppressed email destination to remove from the account suppression list.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.sesv2.suppressed_destination.delete(ctx, email_address=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.sesv2.suppressed_destination.delete email_address=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="sesv2",
        operation="delete_suppressed_destination",
        op_kwargs={"EmailAddress": email_address},
    )


async def get(hub, ctx, email_address: str) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves information about a specific email address that's on the suppression list for your account.

    Args:
        email_address(str): The email address that's on the account suppression list.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.sesv2.suppressed_destination.get(ctx, email_address=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.sesv2.suppressed_destination.get email_address=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="sesv2",
        operation="get_suppressed_destination",
        op_kwargs={"EmailAddress": email_address},
    )


async def list_all(
    hub,
    ctx,
    reasons: List = None,
    start_date: str = None,
    end_date: str = None,
    next_token: str = None,
    page_size: int = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves a list of email addresses that are on the suppression list for your account.

    Args:
        reasons(List, optional): The factors that caused the email address to be added to . Defaults to None.
        start_date(str, optional): Used to filter the list of suppressed email destinations so that it only includes addresses that were added to the list after a specific date. The date that you specify should be in Unix time format. Defaults to None.
        end_date(str, optional): Used to filter the list of suppressed email destinations so that it only includes addresses that were added to the list before a specific date. The date that you specify should be in Unix time format. Defaults to None.
        next_token(str, optional): A token returned from a previous call to ListSuppressedDestinations to indicate the position in the list of suppressed email addresses. Defaults to None.
        page_size(int, optional): The number of results to show in a single call to ListSuppressedDestinations. If the number of results is larger than the number you specified in this parameter, then the response includes a NextToken element, which you can use to obtain additional results. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.sesv2.suppressed_destination.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.sesv2.suppressed_destination.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="sesv2",
        operation="list_suppressed_destinations",
        op_kwargs={
            "Reasons": reasons,
            "StartDate": start_date,
            "EndDate": end_date,
            "NextToken": next_token,
            "PageSize": page_size,
        },
    )


async def put(hub, ctx, email_address: str, reason: str) -> Dict:
    r"""
    **Autogenerated function**

    Adds an email address to the suppression list for your account.

    Args:
        email_address(str): The email address that should be added to the suppression list for your account.
        reason(str): The factors that should cause the email address to be added to the suppression list for your account.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.sesv2.suppressed_destination.put(
                ctx, email_address=value, reason=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.sesv2.suppressed_destination.put email_address=value, reason=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="sesv2",
        operation="put_suppressed_destination",
        op_kwargs={"EmailAddress": email_address, "Reason": reason},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def describe_all(hub, ctx, load_balancer_arn: str) -> Dict:
    r"""
    **Autogenerated function**

    Describes the attributes for the specified Application Load Balancer, Network Load Balancer, or Gateway Load Balancer. For more information, see the following:    Load balancer attributes in the Application Load Balancers Guide     Load balancer attributes in the Network Load Balancers Guide     Load balancer attributes in the Gateway Load Balancers Guide

    Args:
        load_balancer_arn(str): The Amazon Resource Name (ARN) of the load balancer.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.elbv2.load_balancer.attribute.describe_all(
                ctx, load_balancer_arn=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.elbv2.load_balancer.attribute.describe_all load_balancer_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="elbv2",
        operation="describe_load_balancer_attributes",
        op_kwargs={"LoadBalancerArn": load_balancer_arn},
    )


async def modify(hub, ctx, load_balancer_arn: str, attributes: List) -> Dict:
    r"""
    **Autogenerated function**

    Modifies the specified attributes of the specified Application Load Balancer, Network Load Balancer, or Gateway Load Balancer. If any of the specified attributes can't be modified as requested, the call fails. Any existing attributes that you do not modify retain their current values.

    Args:
        load_balancer_arn(str): The Amazon Resource Name (ARN) of the load balancer.
        attributes(List): The load balancer attributes.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.elbv2.load_balancer.attribute.modify(
                ctx, load_balancer_arn=value, attributes=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.elbv2.load_balancer.attribute.modify load_balancer_arn=value, attributes=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="elbv2",
        operation="modify_load_balancer_attributes",
        op_kwargs={"LoadBalancerArn": load_balancer_arn, "Attributes": attributes},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def get(hub, ctx, backup_plan_template_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Returns the template specified by its templateId as a backup plan.

    Args:
        backup_plan_template_id(str): Uniquely identifies a stored backup plan template.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.backup.backup.plan.from_.template.get(
                ctx, backup_plan_template_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.backup.backup.plan.from_.template.get backup_plan_template_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="backup",
        operation="get_backup_plan_from_template",
        op_kwargs={"BackupPlanTemplateId": backup_plan_template_id},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


__virtualname__ = "in_license"


async def check(
    hub, ctx, license_consumption_token: str, beneficiary: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    Checks in the specified license. Check in a license when it is no longer in use.

    Args:
        license_consumption_token(str): License consumption token.
        beneficiary(str, optional): License beneficiary. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.license_manager.in_license_.check(
                ctx, license_consumption_token=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.license_manager.in_license.check license_consumption_token=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="license-manager",
        operation="check_in_license",
        op_kwargs={
            "LicenseConsumptionToken": license_consumption_token,
            "Beneficiary": beneficiary,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def delete(hub, ctx, name: str, recipe_version: str) -> Dict:
    r"""
    **Autogenerated function**

    Deletes a single version of a DataBrew recipe.

    Args:
        name(str): The name of the recipe.
        recipe_version(str): The version of the recipe to be deleted. You can specify a numeric versions (X.Y) or LATEST_WORKING. LATEST_PUBLISHED is not supported.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.databrew.recipe.version.delete(
                ctx, name=value, recipe_version=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.databrew.recipe.version.delete name=value, recipe_version=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="databrew",
        operation="delete_recipe_version",
        op_kwargs={"Name": name, "RecipeVersion": recipe_version},
    )


async def list_all(
    hub, ctx, name: str, max_results: int = None, next_token: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    Lists the versions of a particular DataBrew recipe, except for LATEST_WORKING.

    Args:
        max_results(int, optional): The maximum number of results to return in this request. . Defaults to None.
        next_token(str, optional): The token returned by a previous call to retrieve the next set of results. Defaults to None.
        name(str): The name of the recipe for which to return version information.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.databrew.recipe.version.list_all(ctx, name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.databrew.recipe.version.list_all name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="databrew",
        operation="list_recipe_versions",
        op_kwargs={"MaxResults": max_results, "NextToken": next_token, "Name": name},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def describe(
    hub,
    ctx,
    id_: str,
    accept_language: str = None,
    page_token: str = None,
    page_size: int = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Gets information about the specified request operation. Use this operation after calling a request operation (for example, ProvisionProduct, TerminateProvisionedProduct, or UpdateProvisionedProduct).   If a provisioned product was transferred to a new owner using UpdateProvisionedProductProperties, the new owner will be able to describe all past records for that product. The previous owner will no longer be able to describe the records, but will be able to use ListRecordHistory to see the product's history from when he was the owner.

    Args:
        accept_language(str, optional): The language code.    en - English (default)    jp - Japanese    zh - Chinese  . Defaults to None.
        id_(str): The record identifier of the provisioned product. This identifier is returned by the request operation.
        page_token(str, optional): The page token for the next set of results. To retrieve the first set of results, use null. Defaults to None.
        page_size(int, optional): The maximum number of items to return with this call. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.servicecatalog.record.init.describe(ctx, id_=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.servicecatalog.record.init.describe id_=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="servicecatalog",
        operation="describe_record",
        op_kwargs={
            "AcceptLanguage": accept_language,
            "Id": id_,
            "PageToken": page_token,
            "PageSize": page_size,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def list_all(
    hub,
    ctx,
    image_build_version_arn: str,
    max_results: int = None,
    next_token: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    List the Packages that are associated with an Image Build Version, as determined by Amazon EC2 Systems Manager Inventory at build time.

    Args:
        image_build_version_arn(str): Filter results for the ListImagePackages request by the Image Build Version ARN.
        max_results(int, optional): The maxiumum number of results to return from the ListImagePackages request. Defaults to None.
        next_token(str, optional): A token to specify where to start paginating. This is the NextToken from a previously truncated response. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.imagebuilder.image.package.list_all(
                ctx, image_build_version_arn=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.imagebuilder.image.package.list_all image_build_version_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="imagebuilder",
        operation="list_image_packages",
        op_kwargs={
            "imageBuildVersionArn": image_build_version_arn,
            "maxResults": max_results,
            "nextToken": next_token,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def describe_all(hub, ctx, source_type: str = None, filters: List = None) -> Dict:
    r"""
    **Autogenerated function**

    Displays a list of categories for all event source types, or, if specified, for a specified source type. You can see a list of the event categories and source types in  Events in the Amazon RDS User Guide.

    Args:
        source_type(str, optional): The type of source that is generating the events. Valid values: db-instance | db-cluster | db-parameter-group | db-security-group | db-snapshot | db-cluster-snapshot . Defaults to None.
        filters(List, optional): This parameter isn't currently supported. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.rds.event.category.describe_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.rds.event.category.describe_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="rds",
        operation="describe_event_categories",
        op_kwargs={"SourceType": source_type, "Filters": filters},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def describe_all(
    hub, ctx, filters: List = None, max_results: int = None, next_token: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    Returns an array of import tasks for your account, including status information, times, IDs, the Amazon S3 Object URL for the import file, and more.

    Args:
        filters(List, optional): An array of name-value pairs that you provide to filter the results for the DescribeImportTask request to a specific subset of results. Currently, wildcard values aren't supported for filters. Defaults to None.
        max_results(int, optional): The maximum number of results that you want this request to return, up to 100. Defaults to None.
        next_token(str, optional): The token to request a specific page of results. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.discovery.import_task.describe_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.discovery.import_task.describe_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="discovery",
        operation="describe_import_tasks",
        op_kwargs={
            "filters": filters,
            "maxResults": max_results,
            "nextToken": next_token,
        },
    )


async def start(
    hub, ctx, name: str, import_url: str, client_request_token: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    Starts an import task, which allows you to import details of your on-premises environment directly into AWS Migration Hub without having to use the Application Discovery Service (ADS) tools such as the Discovery Connector or Discovery Agent. This gives you the option to perform migration assessment and planning directly from your imported data, including the ability to group your devices as applications and track their migration status. To start an import request, do this:   Download the specially formatted comma separated value (CSV) import template, which you can find here: https://s3-us-west-2.amazonaws.com/templates-7cffcf56-bd96-4b1c-b45b-a5b42f282e46/import_template.csv.   Fill out the template with your server and application data.   Upload your import file to an Amazon S3 bucket, and make a note of it's Object URL. Your import file must be in the CSV format.   Use the console or the StartImportTask command with the AWS CLI or one of the AWS SDKs to import the records from your file.   For more information, including step-by-step procedures, see Migration Hub Import in the AWS Application Discovery Service User Guide.  There are limits to the number of import tasks you can create (and delete) in an AWS account. For more information, see AWS Application Discovery Service Limits in the AWS Application Discovery Service User Guide.

    Args:
        client_request_token(str, optional): Optional. A unique token that you can provide to prevent the same import request from occurring more than once. If you don't provide a token, a token is automatically generated. Sending more than one StartImportTask request with the same client request token will return information about the original import task with that client request token. Defaults to None.
        name(str): A descriptive name for this request. You can use this name to filter future requests related to this import task, such as identifying applications and servers that were included in this import task. We recommend that you use a meaningful name for each import task.
        import_url(str): The URL for your import file that you've uploaded to Amazon S3.  If you're using the AWS CLI, this URL is structured as follows: s3://BucketName/ImportFileName.CSV  .

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.discovery.import_task.start(ctx, name=value, import_url=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.discovery.import_task.start name=value, import_url=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="discovery",
        operation="start_import_task",
        op_kwargs={
            "clientRequestToken": client_request_token,
            "name": name,
            "importUrl": import_url,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def get(hub, ctx, instance_id: str, dry_run: bool = None) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves the encrypted administrator password for a running Windows instance. The Windows password is generated at boot by the EC2Config service or EC2Launch scripts (Windows Server 2016 and later). This usually only happens the first time an instance is launched. For more information, see EC2Config and EC2Launch in the Amazon EC2 User Guide. For the EC2Config service, the password is not generated for rebundled AMIs unless Ec2SetPassword is enabled before bundling. The password is encrypted using the key pair that you specified when you launched the instance. You must provide the corresponding key pair file. When you launch an instance, password generation and encryption may take a few minutes. If you try to retrieve the password before it's available, the output returns an empty string. We recommend that you wait up to 15 minutes after launching an instance before trying to retrieve the generated password.

    Args:
        instance_id(str): The ID of the Windows instance.
        dry_run(bool, optional): Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ec2.password_data.get(ctx, instance_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ec2.password_data.get instance_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ec2",
        operation="get_password_data",
        op_kwargs={"InstanceId": instance_id, "DryRun": dry_run},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def tag(hub, ctx, resource_arn: str, tags: Dict) -> Dict:
    r"""
    **Autogenerated function**

    Adds one or more tags to an associated repository.

    Args:
        resource_arn(str):  The Amazon Resource Name (ARN) of the  RepositoryAssociation  object. You can retrieve this ARN by calling  ListRepositoryAssociations . .
        tags(Dict):  An array of key-value pairs used to tag an associated repository. A tag is a custom attribute label with two parts:    A tag key (for example, CostCenter, Environment, Project, or Secret). Tag keys are case sensitive.   An optional field known as a tag value (for example, 111122223333, Production, or a team name). Omitting the tag value is the same as using an empty string. Like tag keys, tag values are case sensitive.  .

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.codeguru_reviewer.resource.tag(
                ctx, resource_arn=value, tags=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.codeguru_reviewer.resource.tag resource_arn=value, tags=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="codeguru-reviewer",
        operation="tag_resource",
        op_kwargs={"resourceArn": resource_arn, "Tags": tags},
    )


async def untag(hub, ctx, resource_arn: str, tag_keys: List) -> Dict:
    r"""
    **Autogenerated function**

    Removes a tag from an associated repository.

    Args:
        resource_arn(str):  The Amazon Resource Name (ARN) of the  RepositoryAssociation  object. You can retrieve this ARN by calling  ListRepositoryAssociations . .
        tag_keys(List): A list of the keys for each tag you want to remove from an associated repository.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.codeguru_reviewer.resource.untag(
                ctx, resource_arn=value, tag_keys=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.codeguru_reviewer.resource.untag resource_arn=value, tag_keys=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="codeguru-reviewer",
        operation="untag_resource",
        op_kwargs={"resourceArn": resource_arn, "TagKeys": tag_keys},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(hub, ctx, resource_group_tags: List) -> Dict:
    r"""
    **Autogenerated function**

    Creates a resource group using the specified set of tags (key and value pairs) that are used to select the EC2 instances to be included in an Amazon Inspector assessment target. The created resource group is then used to create an Amazon Inspector assessment target. For more information, see CreateAssessmentTarget.

    Args:
        resource_group_tags(List): A collection of keys and an array of possible values, '[{"key":"key1","values":["Value1","Value2"]},{"key":"Key2","values":["Value3"]}]'. For example,'[{"key":"Name","values":["TestEC2Instance"]}]'.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.inspector.resource_group.create(ctx, resource_group_tags=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.inspector.resource_group.create resource_group_tags=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="inspector",
        operation="create_resource_group",
        op_kwargs={"resourceGroupTags": resource_group_tags},
    )


async def describe_all(hub, ctx, resource_group_arns: List) -> Dict:
    r"""
    **Autogenerated function**

    Describes the resource groups that are specified by the ARNs of the resource groups.

    Args:
        resource_group_arns(List): The ARN that specifies the resource group that you want to describe.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.inspector.resource_group.describe_all(
                ctx, resource_group_arns=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.inspector.resource_group.describe_all resource_group_arns=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="inspector",
        operation="describe_resource_groups",
        op_kwargs={"resourceGroupArns": resource_group_arns},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def associate(hub, ctx, package_id: str, domain_name: str) -> Dict:
    r"""
    **Autogenerated function**

    Associates a package with an Amazon ES domain.

    Args:
        package_id(str): Internal ID of the package that you want to associate with a domain. Use DescribePackages to find this value.
        domain_name(str): Name of the domain that you want to associate the package with.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.es.package.init.associate(
                ctx, package_id=value, domain_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.es.package.init.associate package_id=value, domain_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="es",
        operation="associate_package",
        op_kwargs={"PackageID": package_id, "DomainName": domain_name},
    )


async def create(
    hub,
    ctx,
    package_name: str,
    package_type: str,
    package_source: Dict,
    package_description: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Create a package for use with Amazon ES domains.

    Args:
        package_name(str): Unique identifier for the package.
        package_type(str): Type of package. Currently supports only TXT-DICTIONARY.
        package_description(str, optional): Description of the package. Defaults to None.
        package_source(Dict): The customer S3 location PackageSource for importing the package.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.es.package.init.create(
                ctx, package_name=value, package_type=value, package_source=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.es.package.init.create package_name=value, package_type=value, package_source=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="es",
        operation="create_package",
        op_kwargs={
            "PackageName": package_name,
            "PackageType": package_type,
            "PackageDescription": package_description,
            "PackageSource": package_source,
        },
    )


async def delete(hub, ctx, package_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Delete the package.

    Args:
        package_id(str): Internal ID of the package that you want to delete. Use DescribePackages to find this value.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.es.package.init.delete(ctx, package_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.es.package.init.delete package_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="es",
        operation="delete_package",
        op_kwargs={"PackageID": package_id},
    )


async def describe_all(
    hub, ctx, filters: List = None, max_results: int = None, next_token: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    Describes all packages available to Amazon ES. Includes options for filtering, limiting the number of results, and pagination.

    Args:
        filters(List, optional): Only returns packages that match the DescribePackagesFilterList values. Defaults to None.
        max_results(int, optional): Limits results to a maximum number of packages. Defaults to None.
        next_token(str, optional): Used for pagination. Only necessary if a previous API call includes a non-null NextToken value. If provided, returns results for the next page. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.es.package.init.describe_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.es.package.init.describe_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="es",
        operation="describe_packages",
        op_kwargs={
            "Filters": filters,
            "MaxResults": max_results,
            "NextToken": next_token,
        },
    )


async def dissociate(hub, ctx, package_id: str, domain_name: str) -> Dict:
    r"""
    **Autogenerated function**

    Dissociates a package from the Amazon ES domain.

    Args:
        package_id(str): Internal ID of the package that you want to associate with a domain. Use DescribePackages to find this value.
        domain_name(str): Name of the domain that you want to associate the package with.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.es.package.init.dissociate(
                ctx, package_id=value, domain_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.es.package.init.dissociate package_id=value, domain_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="es",
        operation="dissociate_package",
        op_kwargs={"PackageID": package_id, "DomainName": domain_name},
    )


async def update(
    hub,
    ctx,
    package_id: str,
    package_source: Dict,
    package_description: str = None,
    commit_message: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Updates a package for use with Amazon ES domains.

    Args:
        package_id(str): Unique identifier for the package.
        package_source(Dict): The S3 location for importing the package specified as S3BucketName and S3Key.
        package_description(str, optional): New description of the package. Defaults to None.
        commit_message(str, optional): An info message for the new version which will be shown as part of GetPackageVersionHistoryResponse. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.es.package.init.update(
                ctx, package_id=value, package_source=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.es.package.init.update package_id=value, package_source=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="es",
        operation="update_package",
        op_kwargs={
            "PackageID": package_id,
            "PackageSource": package_source,
            "PackageDescription": package_description,
            "CommitMessage": commit_message,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


__func_alias__ = {"list_": "list"}


async def list_(
    hub, ctx, dns_name: str = None, hosted_zone_id: str = None, max_items: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves a list of your hosted zones in lexicographic order. The response includes a HostedZones child element for each hosted zone created by the current account.   ListHostedZonesByName sorts hosted zones by name with the labels reversed. For example:  com.example.www.  Note the trailing dot, which can change the sort order in some circumstances. If the domain name includes escape characters or Punycode, ListHostedZonesByName alphabetizes the domain name using the escaped or Punycoded value, which is the format that Amazon Route 53 saves in its database. For example, to create a hosted zone for exämple.com, you specify ex\344mple.com for the domain name. ListHostedZonesByName alphabetizes it as:  com.ex\344mple.  The labels are reversed and alphabetized using the escaped value. For more information about valid domain name formats, including internationalized domain names, see DNS Domain Name Format in the Amazon Route 53 Developer Guide. Route 53 returns up to 100 items in each response. If you have a lot of hosted zones, use the MaxItems parameter to list them in groups of up to 100. The response includes values that help navigate from one group of MaxItems hosted zones to the next:   The DNSName and HostedZoneId elements in the response contain the values, if any, specified for the dnsname and hostedzoneid parameters in the request that produced the current response.   The MaxItems element in the response contains the value, if any, that you specified for the maxitems parameter in the request that produced the current response.   If the value of IsTruncated in the response is true, there are more hosted zones associated with the current account.  If IsTruncated is false, this response includes the last hosted zone that is associated with the current account. The NextDNSName element and NextHostedZoneId elements are omitted from the response.   The NextDNSName and NextHostedZoneId elements in the response contain the domain name and the hosted zone ID of the next hosted zone that is associated with the current account. If you want to list more hosted zones, make another call to ListHostedZonesByName, and specify the value of NextDNSName and NextHostedZoneId in the dnsname and hostedzoneid parameters, respectively.

    Args:
        dns_name(str, optional): (Optional) For your first request to ListHostedZonesByName, include the dnsname parameter only if you want to specify the name of the first hosted zone in the response. If you don't include the dnsname parameter, Amazon Route 53 returns all of the hosted zones that were created by the current account, in ASCII order. For subsequent requests, include both dnsname and hostedzoneid parameters. For dnsname, specify the value of NextDNSName from the previous response. Defaults to None.
        hosted_zone_id(str, optional): (Optional) For your first request to ListHostedZonesByName, do not include the hostedzoneid parameter. If you have more hosted zones than the value of maxitems, ListHostedZonesByName returns only the first maxitems hosted zones. To get the next group of maxitems hosted zones, submit another request to ListHostedZonesByName and include both dnsname and hostedzoneid parameters. For the value of hostedzoneid, specify the value of the NextHostedZoneId element from the previous response. Defaults to None.
        max_items(str, optional): The maximum number of hosted zones to be included in the response body for this request. If you have more than maxitems hosted zones, then the value of the IsTruncated element in the response is true, and the values of NextDNSName and NextHostedZoneId specify the first hosted zone in the next group of maxitems hosted zones. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.route53.hosted_zone.by.name.list(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.route53.hosted_zone.by.name.list
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="route53",
        operation="list_hosted_zones_by_name",
        op_kwargs={
            "DNSName": dns_name,
            "HostedZoneId": hosted_zone_id,
            "MaxItems": max_items,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def list_all(
    hub, ctx, session_arn: str, max_result: int = None, next_token: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    Returns a list of the actions taken in a TestGridSession.

    Args:
        session_arn(str): The ARN of the session to retrieve.
        max_result(int, optional): The maximum number of sessions to return per response. Defaults to None.
        next_token(str, optional): Pagination token. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.devicefarm.test.grid.session.action.list_all(
                ctx, session_arn=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.devicefarm.test.grid.session.action.list_all session_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="devicefarm",
        operation="list_test_grid_session_actions",
        op_kwargs={
            "sessionArn": session_arn,
            "maxResult": max_result,
            "nextToken": next_token,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""


async def update(
    hub, ctx, instance_id: str, queue_id: str, hours_of_operation_id: str
) -> None:
    r"""
    **Autogenerated function**

    This API is in preview release for Amazon Connect and is subject to change. Updates the hours of operation for the specified queue.

    Args:
        instance_id(str): The identifier of the Amazon Connect instance. You can find the instanceId in the ARN of the instance.
        queue_id(str): The identifier for the queue.
        hours_of_operation_id(str): The identifier for the hours of operation.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.connect.queue.hour_of_operation.update(
                ctx, instance_id=value, queue_id=value, hours_of_operation_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.connect.queue.hour_of_operation.update instance_id=value, queue_id=value, hours_of_operation_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="connect",
        operation="update_queue_hours_of_operation",
        op_kwargs={
            "InstanceId": instance_id,
            "QueueId": queue_id,
            "HoursOfOperationId": hours_of_operation_id,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def delete(hub, ctx, tags: List) -> None:
    r"""
    **Autogenerated function**

    Deletes the specified tags.

    Args:
        tags(List): One or more tags.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.autoscaling.tags.delete(ctx, tags=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.autoscaling.tags.delete tags=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="autoscaling",
        operation="delete_tags",
        op_kwargs={"Tags": tags},
    )


async def describe(
    hub, ctx, filters: List = None, next_token: str = None, max_records: int = None
) -> Dict:
    r"""
    **Autogenerated function**

    Describes the specified tags. You can use filters to limit the results. For example, you can query for the tags for a specific Auto Scaling group. You can specify multiple values for a filter. A tag must match at least one of the specified values for it to be included in the results. You can also specify multiple filters. The result includes information for a particular tag only if it matches all the filters. If there's no match, no special message is returned. For more information, see Tagging Auto Scaling groups and instances in the Amazon EC2 Auto Scaling User Guide.

    Args:
        filters(List, optional): One or more filters to scope the tags to return. The maximum number of filters per filter type (for example, auto-scaling-group) is 1000. Defaults to None.
        next_token(str, optional): The token for the next set of items to return. (You received this token from a previous call.). Defaults to None.
        max_records(int, optional): The maximum number of items to return with this call. The default value is 50 and the maximum value is 100. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.autoscaling.tags.describe(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.autoscaling.tags.describe
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="autoscaling",
        operation="describe_tags",
        op_kwargs={
            "Filters": filters,
            "NextToken": next_token,
            "MaxRecords": max_records,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


__virtualname__ = "rule_set"


async def create(hub, ctx, name: str, rule_set_body: str, tags: List = None) -> Dict:
    r"""
    **Autogenerated function**

    Creates a new rule set for FlexMatch matchmaking. A rule set describes the type of match to create, such as the number and size of teams. It also sets the parameters for acceptable player matches, such as minimum skill level or character type. A rule set is used by a MatchmakingConfiguration.  To create a matchmaking rule set, provide unique rule set name and the rule set body in JSON format. Rule sets must be defined in the same Region as the matchmaking configuration they are used with. Since matchmaking rule sets cannot be edited, it is a good idea to check the rule set syntax using ValidateMatchmakingRuleSet before creating a new rule set.  Learn more     Build a rule set     Design a matchmaker     Matchmaking with FlexMatch     Related actions   CreateMatchmakingConfiguration | DescribeMatchmakingConfigurations | UpdateMatchmakingConfiguration | DeleteMatchmakingConfiguration | CreateMatchmakingRuleSet | DescribeMatchmakingRuleSets | ValidateMatchmakingRuleSet | DeleteMatchmakingRuleSet | All APIs by task

    Args:
        name(str): A unique identifier for the matchmaking rule set. A matchmaking configuration identifies the rule set it uses by this name value. Note that the rule set name is different from the optional name field in the rule set body.
        rule_set_body(str): A collection of matchmaking rules, formatted as a JSON string. Comments are not allowed in JSON, but most elements support a description field.
        tags(List, optional): A list of labels to assign to the new matchmaking rule set resource. Tags are developer-defined key-value pairs. Tagging AWS resources are useful for resource management, access management and cost allocation. For more information, see  Tagging AWS Resources in the AWS General Reference. Once the resource is created, you can use TagResource, UntagResource, and ListTagsForResource to add, remove, and view tags. The maximum tag limit may be lower than stated. See the AWS General Reference for actual tagging limits. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.gamelift.matchmaking.rule_set_.create(
                ctx, name=value, rule_set_body=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.gamelift.matchmaking.rule_set.create name=value, rule_set_body=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="gamelift",
        operation="create_matchmaking_rule_set",
        op_kwargs={"Name": name, "RuleSetBody": rule_set_body, "Tags": tags},
    )


async def delete(hub, ctx, name: str) -> Dict:
    r"""
    **Autogenerated function**

    Deletes an existing matchmaking rule set. To delete the rule set, provide the rule set name. Rule sets cannot be deleted if they are currently being used by a matchmaking configuration.   Learn more     Build a rule set     Related actions   CreateMatchmakingConfiguration | DescribeMatchmakingConfigurations | UpdateMatchmakingConfiguration | DeleteMatchmakingConfiguration | CreateMatchmakingRuleSet | DescribeMatchmakingRuleSets | ValidateMatchmakingRuleSet | DeleteMatchmakingRuleSet | All APIs by task

    Args:
        name(str): A unique identifier for the matchmaking rule set to be deleted. (Note: The rule set name is different from the optional "name" field in the rule set body.) You can use either the rule set name or ARN value.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.gamelift.matchmaking.rule_set_.delete(ctx, name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.gamelift.matchmaking.rule_set.delete name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="gamelift",
        operation="delete_matchmaking_rule_set",
        op_kwargs={"Name": name},
    )


async def describe_all(
    hub, ctx, names: List = None, limit: int = None, next_token: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves the details for FlexMatch matchmaking rule sets. You can request all existing rule sets for the Region, or provide a list of one or more rule set names. When requesting multiple items, use the pagination parameters to retrieve results as a set of sequential pages. If successful, a rule set is returned for each requested name.   Learn more     Build a rule set     Related actions   CreateMatchmakingConfiguration | DescribeMatchmakingConfigurations | UpdateMatchmakingConfiguration | DeleteMatchmakingConfiguration | CreateMatchmakingRuleSet | DescribeMatchmakingRuleSets | ValidateMatchmakingRuleSet | DeleteMatchmakingRuleSet | All APIs by task

    Args:
        names(List, optional): A list of one or more matchmaking rule set names to retrieve details for. (Note: The rule set name is different from the optional "name" field in the rule set body.) You can use either the rule set name or ARN value. . Defaults to None.
        limit(int, optional): The maximum number of results to return. Use this parameter with NextToken to get results as a set of sequential pages. Defaults to None.
        next_token(str, optional): A token that indicates the start of the next sequential page of results. Use the token that is returned with a previous call to this operation. To start at the beginning of the result set, do not specify a value. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.gamelift.matchmaking.rule_set_.describe_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.gamelift.matchmaking.rule_set.describe_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="gamelift",
        operation="describe_matchmaking_rule_sets",
        op_kwargs={"Names": names, "Limit": limit, "NextToken": next_token},
    )


async def validate(hub, ctx, rule_set_body: str) -> Dict:
    r"""
    **Autogenerated function**

    Validates the syntax of a matchmaking rule or rule set. This operation checks that the rule set is using syntactically correct JSON and that it conforms to allowed property expressions. To validate syntax, provide a rule set JSON string.  Learn more     Build a rule set     Related actions   CreateMatchmakingConfiguration | DescribeMatchmakingConfigurations | UpdateMatchmakingConfiguration | DeleteMatchmakingConfiguration | CreateMatchmakingRuleSet | DescribeMatchmakingRuleSets | ValidateMatchmakingRuleSet | DeleteMatchmakingRuleSet | All APIs by task

    Args:
        rule_set_body(str): A collection of matchmaking rules to validate, formatted as a JSON string.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.gamelift.matchmaking.rule_set_.validate(
                ctx, rule_set_body=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.gamelift.matchmaking.rule_set.validate rule_set_body=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="gamelift",
        operation="validate_matchmaking_rule_set",
        op_kwargs={"RuleSetBody": rule_set_body},
    )
